# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/formatter/req_without_query/v3/req_without_query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/formatter/req_without_query/v3/req_without_query.proto\x12/envoy.extensions.formatter.req_without_query.v3\x1a\x1dudpa/annotations/status.proto\"\x11\n\x0fReqWithoutQueryB\xcb\x01\n=io.envoyproxy.envoy.extensions.formatter.req_without_query.v3B\x14ReqWithoutQueryProtoP\x01Zjgithub.com/envoyproxy/go-control-plane/envoy/extensions/formatter/req_without_query/v3;req_without_queryv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.formatter.req_without_query.v3.req_without_query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n=io.envoyproxy.envoy.extensions.formatter.req_without_query.v3B\024ReqWithoutQueryProtoP\001Zjgithub.com/envoyproxy/go-control-plane/envoy/extensions/formatter/req_without_query/v3;req_without_queryv3\272\200\310\321\006\002\020\002'
  _globals['_REQWITHOUTQUERY']._serialized_start=155
  _globals['_REQWITHOUTQUERY']._serialized_end=172
# @@protoc_insertion_point(module_scope)
