# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/rtds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%envoy/service/discovery/v2/rtds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x0b\n\tRtdsDummy\"H\n\x07Runtime\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12&\n\x05layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct2\xf1\x02\n\x17RuntimeDiscoveryService\x12V\n\rStreamRuntime\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12_\n\x0c\x44\x65ltaRuntime\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12q\n\x0c\x46\x65tchRuntime\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v2/discovery:runtime:\x01*\x1a*\x8a\xa4\x96\xf3\x07$\n\"envoy.service.discovery.v2.RuntimeB\xae\x01\n(io.envoyproxy.envoy.service.discovery.v2B\tRtdsProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\xf2\x98\xfe\x8f\x05\x1a\x12\x18\x65nvoy.service.runtime.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.discovery.v2.rtds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.discovery.v2B\tRtdsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\362\230\376\217\005\032\022\030envoy.service.runtime.v3\272\200\310\321\006\002\020\001'
  _RUNTIME.fields_by_name['name']._options = None
  _RUNTIME.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _RUNTIMEDISCOVERYSERVICE._options = None
  _RUNTIMEDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007$\n\"envoy.service.discovery.v2.Runtime'
  _RUNTIMEDISCOVERYSERVICE.methods_by_name['FetchRuntime']._options = None
  _RUNTIMEDISCOVERYSERVICE.methods_by_name['FetchRuntime']._serialized_options = b'\202\323\344\223\002\032\"\025/v2/discovery:runtime:\001*'
  _globals['_RTDSDUMMY']._serialized_start=281
  _globals['_RTDSDUMMY']._serialized_end=292
  _globals['_RUNTIME']._serialized_start=294
  _globals['_RUNTIME']._serialized_end=366
  _globals['_RUNTIMEDISCOVERYSERVICE']._serialized_start=369
  _globals['_RUNTIMEDISCOVERYSERVICE']._serialized_end=738
# @@protoc_insertion_point(module_scope)
