# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x65nvoy/api/v2/core/address.proto\x12\x11\x65nvoy.api.v2.core\x1a%envoy/api/v2/core/socket_option.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"5\n\x04Pipe\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x16\n\x04mode\x18\x02 \x01(\rB\x08\xfa\x42\x05*\x03\x18\xff\x03\"\x88\x02\n\rSocketAddress\x12\x45\n\x08protocol\x18\x01 \x01(\x0e\x32).envoy.api.v2.core.SocketAddress.ProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x1f\n\nport_value\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x18\xff\xff\x03H\x00\x12\x14\n\nnamed_port\x18\x04 \x01(\tH\x00\x12\x15\n\rresolver_name\x18\x05 \x01(\t\x12\x13\n\x0bipv4_compat\x18\x06 \x01(\x08\"\x1c\n\x08Protocol\x12\x07\n\x03TCP\x10\x00\x12\x07\n\x03UDP\x10\x01\x42\x15\n\x0eport_specifier\x12\x03\xf8\x42\x01\"\xb6\x01\n\x0cTcpKeepalive\x12\x36\n\x10keepalive_probes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x0ekeepalive_time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x38\n\x12keepalive_interval\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"\xb7\x01\n\nBindConfig\x12\x42\n\x0esource_address\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddressB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12,\n\x08\x66reebind\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x0esocket_options\x18\x03 \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\"~\n\x07\x41\x64\x64ress\x12:\n\x0esocket_address\x18\x01 \x01(\x0b\x32 .envoy.api.v2.core.SocketAddressH\x00\x12\'\n\x04pipe\x18\x02 \x01(\x0b\x32\x17.envoy.api.v2.core.PipeH\x00\x42\x0e\n\x07\x61\x64\x64ress\x12\x03\xf8\x42\x01\"h\n\tCidrRange\x12\x1f\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12:\n\nprefix_len\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05*\x03\x18\x80\x01\x42\x8f\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x0c\x41\x64\x64ressProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.address_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\014AddressProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _PIPE.fields_by_name['path']._options = None
  _PIPE.fields_by_name['path']._serialized_options = b'\372B\004r\002 \001'
  _PIPE.fields_by_name['mode']._options = None
  _PIPE.fields_by_name['mode']._serialized_options = b'\372B\005*\003\030\377\003'
  _SOCKETADDRESS.oneofs_by_name['port_specifier']._options = None
  _SOCKETADDRESS.oneofs_by_name['port_specifier']._serialized_options = b'\370B\001'
  _SOCKETADDRESS.fields_by_name['protocol']._options = None
  _SOCKETADDRESS.fields_by_name['protocol']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SOCKETADDRESS.fields_by_name['address']._options = None
  _SOCKETADDRESS.fields_by_name['address']._serialized_options = b'\372B\004r\002 \001'
  _SOCKETADDRESS.fields_by_name['port_value']._options = None
  _SOCKETADDRESS.fields_by_name['port_value']._serialized_options = b'\372B\006*\004\030\377\377\003'
  _BINDCONFIG.fields_by_name['source_address']._options = None
  _BINDCONFIG.fields_by_name['source_address']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ADDRESS.oneofs_by_name['address']._options = None
  _ADDRESS.oneofs_by_name['address']._serialized_options = b'\370B\001'
  _CIDRRANGE.fields_by_name['address_prefix']._options = None
  _CIDRRANGE.fields_by_name['address_prefix']._serialized_options = b'\372B\004r\002 \001'
  _CIDRRANGE.fields_by_name['prefix_len']._options = None
  _CIDRRANGE.fields_by_name['prefix_len']._serialized_options = b'\372B\005*\003\030\200\001'
  _globals['_PIPE']._serialized_start=213
  _globals['_PIPE']._serialized_end=266
  _globals['_SOCKETADDRESS']._serialized_start=269
  _globals['_SOCKETADDRESS']._serialized_end=533
  _globals['_SOCKETADDRESS_PROTOCOL']._serialized_start=482
  _globals['_SOCKETADDRESS_PROTOCOL']._serialized_end=510
  _globals['_TCPKEEPALIVE']._serialized_start=536
  _globals['_TCPKEEPALIVE']._serialized_end=718
  _globals['_BINDCONFIG']._serialized_start=721
  _globals['_BINDCONFIG']._serialized_end=904
  _globals['_ADDRESS']._serialized_start=906
  _globals['_ADDRESS']._serialized_end=1032
  _globals['_CIDRRANGE']._serialized_start=1034
  _globals['_CIDRRANGE']._serialized_end=1138
# @@protoc_insertion_point(module_scope)
