# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/v3/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<envoy/extensions/filters/network/thrift_proxy/v3/route.proto\x12\x30\x65nvoy.extensions.filters.network.thrift_proxy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xef\x01\n\x12RouteConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12G\n\x06routes\x18\x02 \x03(\x0b\x32\x37.envoy.extensions.filters.network.thrift_proxy.v3.Route\x12\x35\n\x11validate_clusters\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:K\x9a\xc5\x88\x1e\x46\nDenvoy.config.filter.network.thrift_proxy.v2alpha1.RouteConfiguration\"\xf6\x01\n\x05Route\x12U\n\x05match\x18\x01 \x01(\x0b\x32<.envoy.extensions.filters.network.thrift_proxy.v3.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12V\n\x05route\x18\x02 \x01(\x0b\x32=.envoy.extensions.filters.network.thrift_proxy.v3.RouteActionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:>\x9a\xc5\x88\x1e\x39\n7envoy.config.filter.network.thrift_proxy.v2alpha1.Route\"\xdf\x01\n\nRouteMatch\x12\x15\n\x0bmethod_name\x18\x01 \x01(\tH\x00\x12\x16\n\x0cservice_name\x18\x02 \x01(\tH\x00\x12\x0e\n\x06invert\x18\x03 \x01(\x08\x12\x35\n\x07headers\x18\x04 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher:C\x9a\xc5\x88\x1e>\n<envoy.config.filter.network.thrift_proxy.v2alpha1.RouteMatchB\x16\n\x0fmatch_specifier\x12\x03\xf8\x42\x01\"\x8c\x05\n\x0bRouteAction\x12\x1a\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12^\n\x11weighted_clusters\x18\x02 \x01(\x0b\x32\x41.envoy.extensions.filters.network.thrift_proxy.v3.WeightedClusterH\x00\x12\'\n\x0e\x63luster_header\x18\x06 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x02\xc8\x01\x00H\x00\x12\x36\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata\x12\x35\n\x0brate_limits\x18\x04 \x03(\x0b\x32 .envoy.config.route.v3.RateLimit\x12\x1a\n\x12strip_service_name\x18\x05 \x01(\x08\x12r\n\x17request_mirror_policies\x18\x07 \x03(\x0b\x32Q.envoy.extensions.filters.network.thrift_proxy.v3.RouteAction.RequestMirrorPolicy\x1ay\n\x13RequestMirrorPolicy\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12H\n\x10runtime_fraction\x18\x02 \x01(\x0b\x32..envoy.config.core.v3.RuntimeFractionalPercent:D\x9a\xc5\x88\x1e?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.RouteActionB\x18\n\x11\x63luster_specifier\x12\x03\xf8\x42\x01\"\xb8\x03\n\x0fWeightedCluster\x12k\n\x08\x63lusters\x18\x01 \x03(\x0b\x32O.envoy.extensions.filters.network.thrift_proxy.v3.WeightedCluster.ClusterWeightB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xed\x01\n\rClusterWeight\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x35\n\x06weight\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02(\x01\x12\x36\n\x0emetadata_match\x18\x03 \x01(\x0b\x32\x1e.envoy.config.core.v3.Metadata:V\x9a\xc5\x88\x1eQ\nOenvoy.config.filter.network.thrift_proxy.v2alpha1.WeightedCluster.ClusterWeight:H\x9a\xc5\x88\x1e\x43\nAenvoy.config.filter.network.thrift_proxy.v2alpha1.WeightedClusterB\xbe\x01\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\nRouteProtoP\x01Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/v3;thrift_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.thrift_proxy.v3.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.network.thrift_proxy.v3B\nRouteProtoP\001Zfgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/v3;thrift_proxyv3\272\200\310\321\006\002\020\002'
  _ROUTECONFIGURATION._options = None
  _ROUTECONFIGURATION._serialized_options = b'\232\305\210\036F\nDenvoy.config.filter.network.thrift_proxy.v2alpha1.RouteConfiguration'
  _ROUTE.fields_by_name['match']._options = None
  _ROUTE.fields_by_name['match']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE.fields_by_name['route']._options = None
  _ROUTE.fields_by_name['route']._serialized_options = b'\372B\005\212\001\002\020\001'
  _ROUTE._options = None
  _ROUTE._serialized_options = b'\232\305\210\0369\n7envoy.config.filter.network.thrift_proxy.v2alpha1.Route'
  _ROUTEMATCH.oneofs_by_name['match_specifier']._options = None
  _ROUTEMATCH.oneofs_by_name['match_specifier']._serialized_options = b'\370B\001'
  _ROUTEMATCH._options = None
  _ROUTEMATCH._serialized_options = b'\232\305\210\036>\n<envoy.config.filter.network.thrift_proxy.v2alpha1.RouteMatch'
  _ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['cluster']._options = None
  _ROUTEACTION_REQUESTMIRRORPOLICY.fields_by_name['cluster']._serialized_options = b'\372B\004r\002\020\001'
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._options = None
  _ROUTEACTION.oneofs_by_name['cluster_specifier']._serialized_options = b'\370B\001'
  _ROUTEACTION.fields_by_name['cluster']._options = None
  _ROUTEACTION.fields_by_name['cluster']._serialized_options = b'\372B\004r\002\020\001'
  _ROUTEACTION.fields_by_name['cluster_header']._options = None
  _ROUTEACTION.fields_by_name['cluster_header']._serialized_options = b'\372B\nr\010\020\001\300\001\002\310\001\000'
  _ROUTEACTION._options = None
  _ROUTEACTION._serialized_options = b'\232\305\210\036?\n=envoy.config.filter.network.thrift_proxy.v2alpha1.RouteAction'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT.fields_by_name['weight']._serialized_options = b'\372B\004*\002(\001'
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT._options = None
  _WEIGHTEDCLUSTER_CLUSTERWEIGHT._serialized_options = b'\232\305\210\036Q\nOenvoy.config.filter.network.thrift_proxy.v2alpha1.WeightedCluster.ClusterWeight'
  _WEIGHTEDCLUSTER.fields_by_name['clusters']._options = None
  _WEIGHTEDCLUSTER.fields_by_name['clusters']._serialized_options = b'\372B\005\222\001\002\010\001'
  _WEIGHTEDCLUSTER._options = None
  _WEIGHTEDCLUSTER._serialized_options = b'\232\305\210\036C\nAenvoy.config.filter.network.thrift_proxy.v2alpha1.WeightedCluster'
  _globals['_ROUTECONFIGURATION']._serialized_start=317
  _globals['_ROUTECONFIGURATION']._serialized_end=556
  _globals['_ROUTE']._serialized_start=559
  _globals['_ROUTE']._serialized_end=805
  _globals['_ROUTEMATCH']._serialized_start=808
  _globals['_ROUTEMATCH']._serialized_end=1031
  _globals['_ROUTEACTION']._serialized_start=1034
  _globals['_ROUTEACTION']._serialized_end=1686
  _globals['_ROUTEACTION_REQUESTMIRRORPOLICY']._serialized_start=1469
  _globals['_ROUTEACTION_REQUESTMIRRORPOLICY']._serialized_end=1590
  _globals['_WEIGHTEDCLUSTER']._serialized_start=1689
  _globals['_WEIGHTEDCLUSTER']._serialized_end=2129
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_start=1818
  _globals['_WEIGHTEDCLUSTER_CLUSTERWEIGHT']._serialized_end=2055
# @@protoc_insertion_point(module_scope)
