# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/zookeeper_proxy/v3/zookeeper_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIenvoy/extensions/filters/network/zookeeper_proxy/v3/zookeeper_proxy.proto\x12\x33\x65nvoy.extensions.filters.network.zookeeper_proxy.v3\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x03\n\x0eZooKeeperProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\naccess_log\x18\x02 \x01(\t\x12\x36\n\x10max_packet_bytes\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12(\n enable_latency_threshold_metrics\x18\x04 \x01(\x08\x12J\n\x19\x64\x65\x66\x61ult_latency_threshold\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=\x12r\n\x1blatency_threshold_overrides\x18\x06 \x03(\x0b\x32M.envoy.extensions.filters.network.zookeeper_proxy.v3.LatencyThresholdOverride:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.network.zookeeper_proxy.v1alpha1.ZooKeeperProxy\"\xcd\x04\n\x18LatencyThresholdOverride\x12n\n\x06opcode\x18\x01 \x01(\x0e\x32T.envoy.extensions.filters.network.zookeeper_proxy.v3.LatencyThresholdOverride.OpcodeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\tthreshold\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xfa\x42\x0b\xaa\x01\x08\x08\x01\x32\x04\x10\xc0\x84=\"\x82\x03\n\x06Opcode\x12\x0b\n\x07\x43onnect\x10\x00\x12\n\n\x06\x43reate\x10\x01\x12\n\n\x06\x44\x65lete\x10\x02\x12\n\n\x06\x45xists\x10\x03\x12\x0b\n\x07GetData\x10\x04\x12\x0b\n\x07SetData\x10\x05\x12\n\n\x06GetAcl\x10\x06\x12\n\n\x06SetAcl\x10\x07\x12\x0f\n\x0bGetChildren\x10\x08\x12\x08\n\x04Sync\x10\t\x12\x08\n\x04Ping\x10\n\x12\x10\n\x0cGetChildren2\x10\x0b\x12\t\n\x05\x43heck\x10\x0c\x12\t\n\x05Multi\x10\r\x12\x0b\n\x07\x43reate2\x10\x0e\x12\x0c\n\x08Reconfig\x10\x0f\x12\x10\n\x0c\x43heckWatches\x10\x10\x12\x11\n\rRemoveWatches\x10\x11\x12\x13\n\x0f\x43reateContainer\x10\x12\x12\r\n\tCreateTtl\x10\x13\x12\t\n\x05\x43lose\x10\x14\x12\x0b\n\x07SetAuth\x10\x15\x12\x0e\n\nSetWatches\x10\x16\x12\x11\n\rGetEphemerals\x10\x17\x12\x18\n\x14GetAllChildrenNumber\x10\x18\x12\x0f\n\x0bSetWatches2\x10\x19\x42\xd0\x01\nAio.envoyproxy.envoy.extensions.filters.network.zookeeper_proxy.v3B\x13ZookeeperProxyProtoP\x01Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/zookeeper_proxy/v3;zookeeper_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.zookeeper_proxy.v3.zookeeper_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nAio.envoyproxy.envoy.extensions.filters.network.zookeeper_proxy.v3B\023ZookeeperProxyProtoP\001Zlgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/zookeeper_proxy/v3;zookeeper_proxyv3\272\200\310\321\006\002\020\002'
  _ZOOKEEPERPROXY.fields_by_name['stat_prefix']._options = None
  _ZOOKEEPERPROXY.fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _ZOOKEEPERPROXY.fields_by_name['default_latency_threshold']._options = None
  _ZOOKEEPERPROXY.fields_by_name['default_latency_threshold']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _ZOOKEEPERPROXY._options = None
  _ZOOKEEPERPROXY._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.network.zookeeper_proxy.v1alpha1.ZooKeeperProxy'
  _LATENCYTHRESHOLDOVERRIDE.fields_by_name['opcode']._options = None
  _LATENCYTHRESHOLDOVERRIDE.fields_by_name['opcode']._serialized_options = b'\372B\005\202\001\002\020\001'
  _LATENCYTHRESHOLDOVERRIDE.fields_by_name['threshold']._options = None
  _LATENCYTHRESHOLDOVERRIDE.fields_by_name['threshold']._serialized_options = b'\372B\013\252\001\010\010\0012\004\020\300\204='
  _globals['_ZOOKEEPERPROXY']._serialized_start=286
  _globals['_ZOOKEEPERPROXY']._serialized_end=718
  _globals['_LATENCYTHRESHOLDOVERRIDE']._serialized_start=721
  _globals['_LATENCYTHRESHOLDOVERRIDE']._serialized_end=1310
  _globals['_LATENCYTHRESHOLDOVERRIDE_OPCODE']._serialized_start=924
  _globals['_LATENCYTHRESHOLDOVERRIDE_OPCODE']._serialized_end=1310
# @@protoc_insertion_point(module_scope)
