# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/eds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import endpoint_pb2 as envoy_dot_api_dot_v2_dot_endpoint__pb2

from envoy.api.v2.endpoint_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65nvoy/api/v2/eds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x1b\x65nvoy/api/v2/endpoint.proto\"\n\n\x08\x45\x64sDummy2\xfa\x02\n\x18\x45ndpointDiscoveryService\x12X\n\x0fStreamEndpoints\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x61\n\x0e\x44\x65ltaEndpoints\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12u\n\x0e\x46\x65tchEndpoints\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v2/discovery:endpoints:\x01*\x1a*\x8a\xa4\x96\xf3\x07$\n\"envoy.api.v2.ClusterLoadAssignmentB\x8c\x01\n\x1aio.envoyproxy.envoy.api.v2B\x08\x45\x64sProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1b\x12\x19\x65nvoy.service.endpoint.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.eds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\010EdsProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\033\022\031envoy.service.endpoint.v3\272\200\310\321\006\002\020\001'
  _ENDPOINTDISCOVERYSERVICE._options = None
  _ENDPOINTDISCOVERYSERVICE._serialized_options = b'\212\244\226\363\007$\n\"envoy.api.v2.ClusterLoadAssignment'
  _ENDPOINTDISCOVERYSERVICE.methods_by_name['FetchEndpoints']._options = None
  _ENDPOINTDISCOVERYSERVICE.methods_by_name['FetchEndpoints']._serialized_options = b'\202\323\344\223\002\034\"\027/v2/discovery:endpoints:\001*'
  _globals['_EDSDUMMY']._serialized_start=226
  _globals['_EDSDUMMY']._serialized_end=236
  _globals['_ENDPOINTDISCOVERYSERVICE']._serialized_start=239
  _globals['_ENDPOINTDISCOVERYSERVICE']._serialized_end=617
# @@protoc_insertion_point(module_scope)
