# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/rbac/audit_loggers/stream/v3/stream.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:envoy/extensions/rbac/audit_loggers/stream/v3/stream.proto\x12-envoy.extensions.rbac.audit_loggers.stream.v3\x1a\x1dudpa/annotations/status.proto\"\x10\n\x0eStdoutAuditLogB\xb3\x01\n;io.envoyproxy.envoy.extensions.rbac.audit_loggers.stream.v3B\x0bStreamProtoP\x01Z]github.com/envoyproxy/go-control-plane/envoy/extensions/rbac/audit_loggers/stream/v3;streamv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.rbac.audit_loggers.stream.v3.stream_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n;io.envoyproxy.envoy.extensions.rbac.audit_loggers.stream.v3B\013StreamProtoP\001Z]github.com/envoyproxy/go-control-plane/envoy/extensions/rbac/audit_loggers/stream/v3;streamv3\272\200\310\321\006\002\020\002'
  _globals['_STDOUTAUDITLOG']._serialized_start=140
  _globals['_STDOUTAUDITLOG']._serialized_end=156
# @@protoc_insertion_point(module_scope)
