# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/dynamic_forward_proxy/v3/dynamic_forward_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRenvoy/extensions/filters/http/dynamic_forward_proxy/v3/dynamic_forward_proxy.proto\x12\x36\x65nvoy.extensions.filters.http.dynamic_forward_proxy.v3\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xdb\x02\n\x0c\x46ilterConfig\x12\\\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigH\x00\x12\x66\n\x12sub_cluster_config\x18\x03 \x01(\x0b\x32H.envoy.extensions.filters.http.dynamic_forward_proxy.v3.SubClusterConfigH\x00\x12\x1d\n\x15save_upstream_address\x18\x02 \x01(\x08:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.http.dynamic_forward_proxy.v2alpha.FilterConfigB\x1a\n\x18implementation_specifier\"\xb7\x01\n\x0ePerRouteConfig\x12\x1e\n\x14host_rewrite_literal\x18\x01 \x01(\tH\x00\x12\x1d\n\x13host_rewrite_header\x18\x02 \x01(\tH\x00:L\x9a\xc5\x88\x1eG\nEenvoy.config.filter.http.dynamic_forward_proxy.v2alpha.PerRouteConfigB\x18\n\x16host_rewrite_specifier\"U\n\x10SubClusterConfig\x12\x41\n\x14\x63luster_init_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x42\xe1\x01\nDio.envoyproxy.envoy.extensions.filters.http.dynamic_forward_proxy.v3B\x18\x44ynamicForwardProxyProtoP\x01Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.dynamic_forward_proxy.v3.dynamic_forward_proxy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nDio.envoyproxy.envoy.extensions.filters.http.dynamic_forward_proxy.v3B\030DynamicForwardProxyProtoP\001Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\272\200\310\321\006\002\020\002'
  _FILTERCONFIG._options = None
  _FILTERCONFIG._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.http.dynamic_forward_proxy.v2alpha.FilterConfig'
  _PERROUTECONFIG._options = None
  _PERROUTECONFIG._serialized_options = b'\232\305\210\036G\nEenvoy.config.filter.http.dynamic_forward_proxy.v2alpha.PerRouteConfig'
  _SUBCLUSTERCONFIG.fields_by_name['cluster_init_timeout']._options = None
  _SUBCLUSTERCONFIG.fields_by_name['cluster_init_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_FILTERCONFIG']._serialized_start=332
  _globals['_FILTERCONFIG']._serialized_end=679
  _globals['_PERROUTECONFIG']._serialized_start=682
  _globals['_PERROUTECONFIG']._serialized_end=865
  _globals['_SUBCLUSTERCONFIG']._serialized_start=867
  _globals['_SUBCLUSTERCONFIG']._serialized_end=952
# @@protoc_insertion_point(module_scope)
