# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/core/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import event_service_config_pb2 as envoy_dot_api_dot_v2_dot_core_dot_event__service__config__pb2
from envoy.type import http_pb2 as envoy_dot_type_dot_http__pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from envoy.type import range_pb2 as envoy_dot_type_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/api/v2/core/health_check.proto\x12\x11\x65nvoy.api.v2.core\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a,envoy/api/v2/core/event_service_config.proto\x1a\x15\x65nvoy/type/http.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x16\x65nvoy/type/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x80\x12\n\x0bHealthCheck\x12\x36\n\x07timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x37\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x31\n\x0einitial_jitter\x18\x14 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0finterval_jitter\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x17interval_jitter_percent\x18\x12 \x01(\r\x12\x43\n\x13unhealthy_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x41\n\x11healthy_threshold\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12.\n\x08\x61lt_port\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x10reuse_connection\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12K\n\x11http_health_check\x18\x08 \x01(\x0b\x32..envoy.api.v2.core.HealthCheck.HttpHealthCheckH\x00\x12I\n\x10tcp_health_check\x18\t \x01(\x0b\x32-.envoy.api.v2.core.HealthCheck.TcpHealthCheckH\x00\x12K\n\x11grpc_health_check\x18\x0b \x01(\x0b\x32..envoy.api.v2.core.HealthCheck.GrpcHealthCheckH\x00\x12O\n\x13\x63ustom_health_check\x18\r \x01(\x0b\x32\x30.envoy.api.v2.core.HealthCheck.CustomHealthCheckH\x00\x12@\n\x13no_traffic_interval\x18\x0c \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12unhealthy_interval\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17unhealthy_edge_interval\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x42\n\x15healthy_edge_interval\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x16\n\x0e\x65vent_log_path\x18\x11 \x01(\t\x12<\n\revent_service\x18\x16 \x01(\x0b\x32%.envoy.api.v2.core.EventServiceConfig\x12(\n always_log_health_check_failures\x18\x13 \x01(\x08\x12>\n\x0btls_options\x18\x15 \x01(\x0b\x32).envoy.api.v2.core.HealthCheck.TlsOptions\x1a\x44\n\x07Payload\x12\x17\n\x04text\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01H\x00\x12\x10\n\x06\x62inary\x18\x02 \x01(\x0cH\x00\x42\x0e\n\x07payload\x12\x03\xf8\x42\x01\x1a\x86\x04\n\x0fHttpHealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x15\n\x04path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x34\n\x04send\x18\x03 \x01(\x0b\x32&.envoy.api.v2.core.HealthCheck.Payload\x12\x37\n\x07receive\x18\x04 \x01(\x0b\x32&.envoy.api.v2.core.HealthCheck.Payload\x12\x18\n\x0cservice_name\x18\x05 \x01(\tB\x02\x18\x01\x12O\n\x16request_headers_to_add\x18\x06 \x03(\x0b\x32$.envoy.api.v2.core.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12!\n\x19request_headers_to_remove\x18\x08 \x03(\t\x12\x1b\n\tuse_http2\x18\x07 \x01(\x08\x42\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x31\n\x11\x65xpected_statuses\x18\t \x03(\x0b\x32\x16.envoy.type.Int64Range\x12@\n\x11\x63odec_client_type\x18\n \x01(\x0e\x32\x1b.envoy.type.CodecClientTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12?\n\x14service_name_matcher\x18\x0b \x01(\x0b\x32!.envoy.type.matcher.StringMatcher\x1a\x7f\n\x0eTcpHealthCheck\x12\x34\n\x04send\x18\x01 \x01(\x0b\x32&.envoy.api.v2.core.HealthCheck.Payload\x12\x37\n\x07receive\x18\x02 \x03(\x0b\x32&.envoy.api.v2.core.HealthCheck.Payload\x1a\x1f\n\x10RedisHealthCheck\x12\x0b\n\x03key\x18\x01 \x01(\t\x1a:\n\x0fGrpcHealthCheck\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x11\n\tauthority\x18\x02 \x01(\t\x1a\x96\x01\n\x11\x43ustomHealthCheck\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12-\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x02\x18\x01H\x00\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x42\r\n\x0b\x63onfig_type\x1a$\n\nTlsOptions\x12\x16\n\x0e\x61lpn_protocols\x18\x01 \x03(\tB\x15\n\x0ehealth_checker\x12\x03\xf8\x42\x01J\x04\x08\n\x10\x0b*`\n\x0cHealthStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\r\n\tUNHEALTHY\x10\x02\x12\x0c\n\x08\x44RAINING\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x44\x45GRADED\x10\x05\x42\x93\x01\n\x1fio.envoyproxy.envoy.api.v2.coreB\x10HealthCheckProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\xf2\x98\xfe\x8f\x05\x16\x12\x14\x65nvoy.config.core.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.core.health_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.coreB\020HealthCheckProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/core\362\230\376\217\005\026\022\024envoy.config.core.v3\272\200\310\321\006\002\020\001'
  _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']._options = None
  _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']._serialized_options = b'\370B\001'
  _HEALTHCHECK_PAYLOAD.fields_by_name['text']._options = None
  _HEALTHCHECK_PAYLOAD.fields_by_name['text']._serialized_options = b'\372B\004r\002 \001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._serialized_options = b'\372B\004r\002 \001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['service_name']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['service_name']._serialized_options = b'\030\001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['use_http2']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['use_http2']._serialized_options = b'\030\001\270\356\362\322\005\001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['name']._options = None
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['name']._serialized_options = b'\372B\004r\002 \001'
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['config']._options = None
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['config']._serialized_options = b'\030\001'
  _HEALTHCHECK.oneofs_by_name['health_checker']._options = None
  _HEALTHCHECK.oneofs_by_name['health_checker']._serialized_options = b'\370B\001'
  _HEALTHCHECK.fields_by_name['timeout']._options = None
  _HEALTHCHECK.fields_by_name['timeout']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _HEALTHCHECK.fields_by_name['interval']._options = None
  _HEALTHCHECK.fields_by_name['interval']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_threshold']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_threshold']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEALTHCHECK.fields_by_name['healthy_threshold']._options = None
  _HEALTHCHECK.fields_by_name['healthy_threshold']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HEALTHCHECK.fields_by_name['no_traffic_interval']._options = None
  _HEALTHCHECK.fields_by_name['no_traffic_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_interval']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['unhealthy_edge_interval']._options = None
  _HEALTHCHECK.fields_by_name['unhealthy_edge_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _HEALTHCHECK.fields_by_name['healthy_edge_interval']._options = None
  _HEALTHCHECK.fields_by_name['healthy_edge_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_HEALTHSTATUS']._serialized_start=2768
  _globals['_HEALTHSTATUS']._serialized_end=2864
  _globals['_HEALTHCHECK']._serialized_start=462
  _globals['_HEALTHCHECK']._serialized_end=2766
  _globals['_HEALTHCHECK_PAYLOAD']._serialized_start=1735
  _globals['_HEALTHCHECK_PAYLOAD']._serialized_end=1803
  _globals['_HEALTHCHECK_HTTPHEALTHCHECK']._serialized_start=1806
  _globals['_HEALTHCHECK_HTTPHEALTHCHECK']._serialized_end=2324
  _globals['_HEALTHCHECK_TCPHEALTHCHECK']._serialized_start=2326
  _globals['_HEALTHCHECK_TCPHEALTHCHECK']._serialized_end=2453
  _globals['_HEALTHCHECK_REDISHEALTHCHECK']._serialized_start=2455
  _globals['_HEALTHCHECK_REDISHEALTHCHECK']._serialized_end=2486
  _globals['_HEALTHCHECK_GRPCHEALTHCHECK']._serialized_start=2488
  _globals['_HEALTHCHECK_GRPCHEALTHCHECK']._serialized_end=2546
  _globals['_HEALTHCHECK_CUSTOMHEALTHCHECK']._serialized_start=2549
  _globals['_HEALTHCHECK_CUSTOMHEALTHCHECK']._serialized_end=2699
  _globals['_HEALTHCHECK_TLSOPTIONS']._serialized_start=2701
  _globals['_HEALTHCHECK_TLSOPTIONS']._serialized_end=2737
# @@protoc_insertion_point(module_scope)
