# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/dns/v3/dns_table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/data/dns/v3/dns_table.proto\x12\x11\x65nvoy.data.dns.v3\x1a\"envoy/type/matcher/v3/string.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x93\x0b\n\x08\x44nsTable\x12%\n\x14\x65xternal_retry_count\x18\x01 \x01(\rB\x07\xfa\x42\x04*\x02\x18\x03\x12\x45\n\x0fvirtual_domains\x18\x02 \x03(\x0b\x32,.envoy.data.dns.v3.DnsTable.DnsVirtualDomain\x12I\n\x0eknown_suffixes\x18\x03 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x1a\x62\n\x0b\x41\x64\x64ressList\x12\x1f\n\x07\x61\x64\x64ress\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02\x10\x03:2\x9a\xc5\x88\x1e-\n+envoy.data.dns.v2alpha.DnsTable.AddressList\x1a\x64\n\x12\x44nsServiceProtocol\x12\x1a\n\x06number\x18\x01 \x01(\rB\x08\xfa\x42\x05*\x03\x10\xff\x01H\x00\x12\x1a\n\x04name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x42\x16\n\x0fprotocol_config\x12\x03\xf8\x42\x01\x1a\xbe\x01\n\x10\x44nsServiceTarget\x12\x1f\n\thost_name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x12\"\n\x0c\x63luster_name\x18\x02 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01H\x00\x12\x1b\n\x08priority\x18\x03 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x12\x19\n\x06weight\x18\x04 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x12\x17\n\x04port\x18\x05 \x01(\rB\t\xfa\x42\x06*\x04\x10\x80\x80\x04\x42\x14\n\rendpoint_type\x12\x03\xf8\x42\x01\x1a\xed\x01\n\nDnsService\x12 \n\x0cservice_name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01\x12@\n\x08protocol\x18\x02 \x01(\x0b\x32..envoy.data.dns.v3.DnsTable.DnsServiceProtocol\x12\x32\n\x03ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x01\x12G\n\x07targets\x18\x04 \x03(\x0b\x32,.envoy.data.dns.v3.DnsTable.DnsServiceTargetB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1aT\n\x0e\x44nsServiceList\x12\x42\n\x08services\x18\x01 \x03(\x0b\x32&.envoy.data.dns.v3.DnsTable.DnsServiceB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xf6\x01\n\x0b\x44nsEndpoint\x12?\n\x0c\x61\x64\x64ress_list\x18\x01 \x01(\x0b\x32\'.envoy.data.dns.v3.DnsTable.AddressListH\x00\x12\x16\n\x0c\x63luster_name\x18\x02 \x01(\tH\x00\x12\x42\n\x0cservice_list\x18\x03 \x01(\x0b\x32*.envoy.data.dns.v3.DnsTable.DnsServiceListH\x00:2\x9a\xc5\x88\x1e-\n+envoy.data.dns.v2alpha.DnsTable.DnsEndpointB\x16\n\x0f\x65ndpoint_config\x12\x03\xf8\x42\x01\x1a\xdb\x01\n\x10\x44nsVirtualDomain\x12\x18\n\x04name\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05\x10\x01\xc0\x01\x01\x12\x39\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32\'.envoy.data.dns.v3.DnsTable.DnsEndpoint\x12\x39\n\nanswer_ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x1e:7\x9a\xc5\x88\x1e\x32\n0envoy.data.dns.v2alpha.DnsTable.DnsVirtualDomain:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.data.dns.v2alpha.DnsTableBz\n\x1fio.envoyproxy.envoy.data.dns.v3B\rDnsTableProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/dns/v3;dnsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.dns.v3.dns_table_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037io.envoyproxy.envoy.data.dns.v3B\rDnsTableProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/dns/v3;dnsv3\272\200\310\321\006\002\020\002'
  _DNSTABLE_ADDRESSLIST.fields_by_name['address']._options = None
  _DNSTABLE_ADDRESSLIST.fields_by_name['address']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002\020\003'
  _DNSTABLE_ADDRESSLIST._options = None
  _DNSTABLE_ADDRESSLIST._serialized_options = b'\232\305\210\036-\n+envoy.data.dns.v2alpha.DnsTable.AddressList'
  _DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config']._options = None
  _DNSTABLE_DNSSERVICEPROTOCOL.oneofs_by_name['protocol_config']._serialized_options = b'\370B\001'
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['number']._options = None
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['number']._serialized_options = b'\372B\005*\003\020\377\001'
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['name']._options = None
  _DNSTABLE_DNSSERVICEPROTOCOL.fields_by_name['name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type']._options = None
  _DNSTABLE_DNSSERVICETARGET.oneofs_by_name['endpoint_type']._serialized_options = b'\370B\001'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['host_name']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['host_name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['cluster_name']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['cluster_name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['priority']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['priority']._serialized_options = b'\372B\006*\004\020\200\200\004'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['weight']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['weight']._serialized_options = b'\372B\006*\004\020\200\200\004'
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['port']._options = None
  _DNSTABLE_DNSSERVICETARGET.fields_by_name['port']._serialized_options = b'\372B\006*\004\020\200\200\004'
  _DNSTABLE_DNSSERVICE.fields_by_name['service_name']._options = None
  _DNSTABLE_DNSSERVICE.fields_by_name['service_name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSSERVICE.fields_by_name['ttl']._options = None
  _DNSTABLE_DNSSERVICE.fields_by_name['ttl']._serialized_options = b'\372B\007\252\001\0042\002\010\001'
  _DNSTABLE_DNSSERVICE.fields_by_name['targets']._options = None
  _DNSTABLE_DNSSERVICE.fields_by_name['targets']._serialized_options = b'\372B\005\222\001\002\010\001'
  _DNSTABLE_DNSSERVICELIST.fields_by_name['services']._options = None
  _DNSTABLE_DNSSERVICELIST.fields_by_name['services']._serialized_options = b'\372B\005\222\001\002\010\001'
  _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']._options = None
  _DNSTABLE_DNSENDPOINT.oneofs_by_name['endpoint_config']._serialized_options = b'\370B\001'
  _DNSTABLE_DNSENDPOINT._options = None
  _DNSTABLE_DNSENDPOINT._serialized_options = b'\232\305\210\036-\n+envoy.data.dns.v2alpha.DnsTable.DnsEndpoint'
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['name']._options = None
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['name']._serialized_options = b'\372B\007r\005\020\001\300\001\001'
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['answer_ttl']._options = None
  _DNSTABLE_DNSVIRTUALDOMAIN.fields_by_name['answer_ttl']._serialized_options = b'\372B\007\252\001\0042\002\010\036'
  _DNSTABLE_DNSVIRTUALDOMAIN._options = None
  _DNSTABLE_DNSVIRTUALDOMAIN._serialized_options = b'\232\305\210\0362\n0envoy.data.dns.v2alpha.DnsTable.DnsVirtualDomain'
  _DNSTABLE.fields_by_name['external_retry_count']._options = None
  _DNSTABLE.fields_by_name['external_retry_count']._serialized_options = b'\372B\004*\002\030\003'
  _DNSTABLE.fields_by_name['known_suffixes']._options = None
  _DNSTABLE.fields_by_name['known_suffixes']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _DNSTABLE._options = None
  _DNSTABLE._serialized_options = b'\232\305\210\036!\n\037envoy.data.dns.v2alpha.DnsTable'
  _globals['_DNSTABLE']._serialized_start=253
  _globals['_DNSTABLE']._serialized_end=1680
  _globals['_DNSTABLE_ADDRESSLIST']._serialized_start=450
  _globals['_DNSTABLE_ADDRESSLIST']._serialized_end=548
  _globals['_DNSTABLE_DNSSERVICEPROTOCOL']._serialized_start=550
  _globals['_DNSTABLE_DNSSERVICEPROTOCOL']._serialized_end=650
  _globals['_DNSTABLE_DNSSERVICETARGET']._serialized_start=653
  _globals['_DNSTABLE_DNSSERVICETARGET']._serialized_end=843
  _globals['_DNSTABLE_DNSSERVICE']._serialized_start=846
  _globals['_DNSTABLE_DNSSERVICE']._serialized_end=1083
  _globals['_DNSTABLE_DNSSERVICELIST']._serialized_start=1085
  _globals['_DNSTABLE_DNSSERVICELIST']._serialized_end=1169
  _globals['_DNSTABLE_DNSENDPOINT']._serialized_start=1172
  _globals['_DNSTABLE_DNSENDPOINT']._serialized_end=1418
  _globals['_DNSTABLE_DNSVIRTUALDOMAIN']._serialized_start=1421
  _globals['_DNSTABLE_DNSVIRTUALDOMAIN']._serialized_end=1640
# @@protoc_insertion_point(module_scope)
