# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/filters/cel/v3/cel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8envoy/extensions/access_loggers/filters/cel/v3/cel.proto\x12.envoy.extensions.access_loggers.filters.cel.v3\x1a\x1dudpa/annotations/status.proto\"&\n\x10\x45xpressionFilter\x12\x12\n\nexpression\x18\x01 \x01(\tB\xaf\x01\n<io.envoyproxy.envoy.extensions.access_loggers.filters.cel.v3B\x08\x43\x65lProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/filters/cel/v3;celv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.filters.cel.v3.cel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<io.envoyproxy.envoy.extensions.access_loggers.filters.cel.v3B\010CelProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/filters/cel/v3;celv3\272\200\310\321\006\002\020\002'
  _globals['_EXPRESSIONFILTER']._serialized_start=139
  _globals['_EXPRESSIONFILTER']._serialized_end=177
# @@protoc_insertion_point(module_scope)
