# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/thrift_proxy/filters/payload_to_metadata/v3/payload_to_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.matcher.v3 import regex_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_regex__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nfenvoy/extensions/filters/network/thrift_proxy/filters/payload_to_metadata/v3/payload_to_metadata.proto\x12Lenvoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3\x1a!envoy/type/matcher/v3/regex.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa6\t\n\x11PayloadToMetadata\x12\x85\x01\n\rrequest_rules\x18\x01 \x03(\x0b\x32\x64.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.RuleB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1a\xb2\x02\n\x0cKeyValuePair\x12\x1a\n\x12metadata_namespace\x18\x01 \x01(\t\x12\x14\n\x03key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0f\n\x05value\x18\x03 \x01(\tH\x00\x12M\n\x13regex_value_rewrite\x18\x04 \x01(\x0b\x32..envoy.type.matcher.v3.RegexMatchAndSubstituteH\x00\x12\x81\x01\n\x04type\x18\x05 \x01(\x0e\x32i.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.ValueTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x42\x0c\n\nvalue_type\x1a\xe5\x03\n\x04Rule\x12\x15\n\x0bmethod_name\x18\x01 \x01(\tH\x00\x12\x16\n\x0cservice_name\x18\x02 \x01(\tH\x00\x12\x8f\x01\n\x0e\x66ield_selector\x18\x03 \x01(\x0b\x32m.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.FieldSelectorB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x80\x01\n\non_present\x18\x04 \x01(\x0b\x32l.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.KeyValuePair\x12\x80\x01\n\non_missing\x18\x05 \x01(\x0b\x32l.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.KeyValuePairB\x16\n\x0fmatch_specifier\x12\x03\xf8\x42\x01\x1a\xc6\x01\n\rFieldSelector\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12 \n\x02id\x18\x02 \x01(\x05\x42\x14\xfa\x42\x11\x1a\x0f\x18\xff\xff\x01(\x80\x80\xfe\xff\xff\xff\xff\xff\xff\x01\x12|\n\x05\x63hild\x18\x03 \x01(\x0b\x32m.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.PayloadToMetadata.FieldSelector\"#\n\tValueType\x12\n\n\x06STRING\x10\x00\x12\n\n\x06NUMBER\x10\x01\x42\x8a\x02\nZio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3B\x16PayloadToMetadataProtoP\x01Z\x89\x01github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/filters/payload_to_metadata/v3;payload_to_metadatav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3.payload_to_metadata_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nZio.envoyproxy.envoy.extensions.filters.network.thrift_proxy.filters.payload_to_metadata.v3B\026PayloadToMetadataProtoP\001Z\211\001github.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/thrift_proxy/filters/payload_to_metadata/v3;payload_to_metadatav3\272\200\310\321\006\002\020\002'
  _PAYLOADTOMETADATA_KEYVALUEPAIR.fields_by_name['key']._options = None
  _PAYLOADTOMETADATA_KEYVALUEPAIR.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _PAYLOADTOMETADATA_KEYVALUEPAIR.fields_by_name['type']._options = None
  _PAYLOADTOMETADATA_KEYVALUEPAIR.fields_by_name['type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _PAYLOADTOMETADATA_RULE.oneofs_by_name['match_specifier']._options = None
  _PAYLOADTOMETADATA_RULE.oneofs_by_name['match_specifier']._serialized_options = b'\370B\001'
  _PAYLOADTOMETADATA_RULE.fields_by_name['field_selector']._options = None
  _PAYLOADTOMETADATA_RULE.fields_by_name['field_selector']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PAYLOADTOMETADATA_FIELDSELECTOR.fields_by_name['name']._options = None
  _PAYLOADTOMETADATA_FIELDSELECTOR.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _PAYLOADTOMETADATA_FIELDSELECTOR.fields_by_name['id']._options = None
  _PAYLOADTOMETADATA_FIELDSELECTOR.fields_by_name['id']._serialized_options = b'\372B\021\032\017\030\377\377\001(\200\200\376\377\377\377\377\377\377\001'
  _PAYLOADTOMETADATA.fields_by_name['request_rules']._options = None
  _PAYLOADTOMETADATA.fields_by_name['request_rules']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_PAYLOADTOMETADATA']._serialized_start=276
  _globals['_PAYLOADTOMETADATA']._serialized_end=1466
  _globals['_PAYLOADTOMETADATA_KEYVALUEPAIR']._serialized_start=434
  _globals['_PAYLOADTOMETADATA_KEYVALUEPAIR']._serialized_end=740
  _globals['_PAYLOADTOMETADATA_RULE']._serialized_start=743
  _globals['_PAYLOADTOMETADATA_RULE']._serialized_end=1228
  _globals['_PAYLOADTOMETADATA_FIELDSELECTOR']._serialized_start=1231
  _globals['_PAYLOADTOMETADATA_FIELDSELECTOR']._serialized_end=1429
  _globals['_PAYLOADTOMETADATA_VALUETYPE']._serialized_start=1431
  _globals['_PAYLOADTOMETADATA_VALUETYPE']._serialized_end=1466
# @@protoc_insertion_point(module_scope)
