# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6envoy/extensions/transport_sockets/tls/v3/common.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbe\x03\n\rTlsParameters\x12t\n\x1ctls_minimum_protocol_version\x18\x01 \x01(\x0e\x32\x44.envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12t\n\x1ctls_maximum_protocol_version\x18\x02 \x01(\x0e\x32\x44.envoy.extensions.transport_sockets.tls.v3.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcipher_suites\x18\x03 \x03(\t\x12\x13\n\x0b\x65\x63\x64h_curves\x18\x04 \x03(\t\x12\x1c\n\x14signature_algorithms\x18\x05 \x03(\t\"O\n\x0bTlsProtocol\x12\x0c\n\x08TLS_AUTO\x10\x00\x12\x0b\n\x07TLSv1_0\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.api.v2.auth.TlsParameters\"\xb4\x01\n\x12PrivateKeyProvider\x12\x1e\n\rprovider_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x34\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00:+\x9a\xc5\x88\x1e&\n$envoy.api.v2.auth.PrivateKeyProviderB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\"\xca\x04\n\x0eTlsCertificate\x12;\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12=\n\x0bprivate_key\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x38\n\x06pkcs12\x18\x08 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x41\n\x11watched_directory\x18\x07 \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\x12[\n\x14private_key_provider\x18\x06 \x01(\x0b\x32=.envoy.extensions.transport_sockets.tls.v3.PrivateKeyProvider\x12:\n\x08password\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x35\n\x0bocsp_staple\x18\x04 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12\x46\n\x1csigned_certificate_timestamp\x18\x05 \x03(\x0b\x32 .envoy.config.core.v3.DataSource:\'\x9a\xc5\x88\x1e\"\n envoy.api.v2.auth.TlsCertificate\"\x85\x01\n\x14TlsSessionTicketKeys\x12>\n\x04keys\x18\x01 \x03(\x0b\x32 .envoy.config.core.v3.DataSourceB\x0e\xfa\x42\x05\x92\x01\x02\x08\x01\xb8\xb7\x8b\xa4\x02\x01:-\x9a\xc5\x88\x1e(\n&envoy.api.v2.auth.TlsSessionTicketKeys\"T\n!CertificateProviderPluginInstance\x12\x15\n\rinstance_name\x18\x01 \x01(\t\x12\x18\n\x10\x63\x65rtificate_name\x18\x02 \x01(\t\"\x92\x02\n\x15SubjectAltNameMatcher\x12\x66\n\x08san_type\x18\x01 \x01(\x0e\x32H.envoy.extensions.transport_sockets.tls.v3.SubjectAltNameMatcher.SanTypeB\n\xfa\x42\x07\x82\x01\x04\x10\x01 \x00\x12?\n\x07matcher\x18\x02 \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"P\n\x07SanType\x12\x18\n\x14SAN_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x45MAIL\x10\x01\x12\x07\n\x03\x44NS\x10\x02\x12\x07\n\x03URI\x10\x03\x12\x0e\n\nIP_ADDRESS\x10\x04\"\xdd\t\n\x1c\x43\x65rtificateValidationContext\x12L\n\ntrusted_ca\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x16\xf2\x98\xfe\x8f\x05\x10\x12\x0e\x63\x61_cert_source\x12\x8e\x01\n ca_certificate_provider_instance\x18\r \x01(\x0b\x32L.envoy.extensions.transport_sockets.tls.v3.CertificateProviderPluginInstanceB\x16\xf2\x98\xfe\x8f\x05\x10\x12\x0e\x63\x61_cert_source\x12\x41\n\x11watched_directory\x18\x0b \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\x12/\n\x17verify_certificate_spki\x18\x03 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04\x10,(,\x12/\n\x17verify_certificate_hash\x18\x02 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04\x10@(_\x12g\n\x1dmatch_typed_subject_alt_names\x18\x0f \x03(\x0b\x32@.envoy.extensions.transport_sockets.tls.v3.SubjectAltNameMatcher\x12R\n\x17match_subject_alt_names\x18\t \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcherB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12H\n$require_signed_certificate_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\x03\x63rl\x18\x07 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12!\n\x19\x61llow_expired_certificate\x18\x08 \x01(\x08\x12\x8a\x01\n\x18trust_chain_verification\x18\n \x01(\x0e\x32^.envoy.extensions.transport_sockets.tls.v3.CertificateValidationContext.TrustChainVerificationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12K\n\x17\x63ustom_validator_config\x18\x0c \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12!\n\x19only_verify_leaf_cert_crl\x18\x0e \x01(\x08\x12?\n\x10max_verify_depth\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02\x18\x64\"F\n\x16TrustChainVerification\x12\x16\n\x12VERIFY_TRUST_CHAIN\x10\x00\x12\x14\n\x10\x41\x43\x43\x45PT_UNTRUSTED\x10\x01:5\x9a\xc5\x88\x1e\x30\n.envoy.api.v2.auth.CertificateValidationContextJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06R\x17verify_subject_alt_nameB\xa8\x01\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\x0b\x43ommonProtoP\x01ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.tls.v3.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\013CommonProtoP\001ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3\272\200\310\321\006\002\020\002'
  _TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version']._options = None
  _TLSPARAMETERS.fields_by_name['tls_minimum_protocol_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version']._options = None
  _TLSPARAMETERS.fields_by_name['tls_maximum_protocol_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _TLSPARAMETERS._options = None
  _TLSPARAMETERS._serialized_options = b'\232\305\210\036!\n\037envoy.api.v2.auth.TlsParameters'
  _PRIVATEKEYPROVIDER.fields_by_name['provider_name']._options = None
  _PRIVATEKEYPROVIDER.fields_by_name['provider_name']._serialized_options = b'\372B\004r\002\020\001'
  _PRIVATEKEYPROVIDER.fields_by_name['typed_config']._options = None
  _PRIVATEKEYPROVIDER.fields_by_name['typed_config']._serialized_options = b'\270\267\213\244\002\001'
  _PRIVATEKEYPROVIDER._options = None
  _PRIVATEKEYPROVIDER._serialized_options = b'\232\305\210\036&\n$envoy.api.v2.auth.PrivateKeyProvider'
  _TLSCERTIFICATE.fields_by_name['private_key']._options = None
  _TLSCERTIFICATE.fields_by_name['private_key']._serialized_options = b'\270\267\213\244\002\001'
  _TLSCERTIFICATE.fields_by_name['pkcs12']._options = None
  _TLSCERTIFICATE.fields_by_name['pkcs12']._serialized_options = b'\270\267\213\244\002\001'
  _TLSCERTIFICATE.fields_by_name['password']._options = None
  _TLSCERTIFICATE.fields_by_name['password']._serialized_options = b'\270\267\213\244\002\001'
  _TLSCERTIFICATE._options = None
  _TLSCERTIFICATE._serialized_options = b'\232\305\210\036\"\n envoy.api.v2.auth.TlsCertificate'
  _TLSSESSIONTICKETKEYS.fields_by_name['keys']._options = None
  _TLSSESSIONTICKETKEYS.fields_by_name['keys']._serialized_options = b'\372B\005\222\001\002\010\001\270\267\213\244\002\001'
  _TLSSESSIONTICKETKEYS._options = None
  _TLSSESSIONTICKETKEYS._serialized_options = b'\232\305\210\036(\n&envoy.api.v2.auth.TlsSessionTicketKeys'
  _SUBJECTALTNAMEMATCHER.fields_by_name['san_type']._options = None
  _SUBJECTALTNAMEMATCHER.fields_by_name['san_type']._serialized_options = b'\372B\007\202\001\004\020\001 \000'
  _SUBJECTALTNAMEMATCHER.fields_by_name['matcher']._options = None
  _SUBJECTALTNAMEMATCHER.fields_by_name['matcher']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trusted_ca']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trusted_ca']._serialized_options = b'\362\230\376\217\005\020\022\016ca_cert_source'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['ca_certificate_provider_instance']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['ca_certificate_provider_instance']._serialized_options = b'\362\230\376\217\005\020\022\016ca_cert_source'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_spki']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_spki']._serialized_options = b'\372B\013\222\001\010\"\006r\004\020,(,'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_hash']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['verify_certificate_hash']._serialized_options = b'\372B\013\222\001\010\"\006r\004\020@(_'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['match_subject_alt_names']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['match_subject_alt_names']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['trust_chain_verification']._serialized_options = b'\372B\005\202\001\002\020\001'
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['max_verify_depth']._options = None
  _CERTIFICATEVALIDATIONCONTEXT.fields_by_name['max_verify_depth']._serialized_options = b'\372B\004*\002\030d'
  _CERTIFICATEVALIDATIONCONTEXT._options = None
  _CERTIFICATEVALIDATIONCONTEXT._serialized_options = b'\232\305\210\0360\n.envoy.api.v2.auth.CertificateValidationContext'
  _globals['_TLSPARAMETERS']._serialized_start=462
  _globals['_TLSPARAMETERS']._serialized_end=908
  _globals['_TLSPARAMETERS_TLSPROTOCOL']._serialized_start=789
  _globals['_TLSPARAMETERS_TLSPROTOCOL']._serialized_end=868
  _globals['_PRIVATEKEYPROVIDER']._serialized_start=911
  _globals['_PRIVATEKEYPROVIDER']._serialized_end=1091
  _globals['_TLSCERTIFICATE']._serialized_start=1094
  _globals['_TLSCERTIFICATE']._serialized_end=1680
  _globals['_TLSSESSIONTICKETKEYS']._serialized_start=1683
  _globals['_TLSSESSIONTICKETKEYS']._serialized_end=1816
  _globals['_CERTIFICATEPROVIDERPLUGININSTANCE']._serialized_start=1818
  _globals['_CERTIFICATEPROVIDERPLUGININSTANCE']._serialized_end=1902
  _globals['_SUBJECTALTNAMEMATCHER']._serialized_start=1905
  _globals['_SUBJECTALTNAMEMATCHER']._serialized_end=2179
  _globals['_SUBJECTALTNAMEMATCHER_SANTYPE']._serialized_start=2099
  _globals['_SUBJECTALTNAMEMATCHER_SANTYPE']._serialized_end=2179
  _globals['_CERTIFICATEVALIDATIONCONTEXT']._serialized_start=2182
  _globals['_CERTIFICATEVALIDATIONCONTEXT']._serialized_end=3427
  _globals['_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION']._serialized_start=3265
  _globals['_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION']._serialized_end=3335
# @@protoc_insertion_point(module_scope)
