# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/access_loggers/grpc/v3/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import config_source_pb2 as envoy_dot_config_dot_core_dot_v3_dot_config__source__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from envoy.type.tracing.v3 import custom_tag_pb2 as envoy_dot_type_dot_tracing_dot_v3_dot_custom__tag__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1envoy/extensions/access_loggers/grpc/v3/als.proto\x12\'envoy.extensions.access_loggers.grpc.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a(envoy/config/core/v3/config_source.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a&envoy/type/tracing/v3/custom_tag.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xbc\x02\n\x17HttpGrpcAccessLogConfig\x12\x63\n\rcommon_config\x18\x01 \x01(\x0b\x32\x42.envoy.extensions.access_loggers.grpc.v3.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12)\n!additional_request_headers_to_log\x18\x02 \x03(\t\x12*\n\"additional_response_headers_to_log\x18\x03 \x03(\t\x12+\n#additional_response_trailers_to_log\x18\x04 \x03(\t:8\x9a\xc5\x88\x1e\x33\n1envoy.config.accesslog.v2.HttpGrpcAccessLogConfig\"\xb6\x01\n\x16TcpGrpcAccessLogConfig\x12\x63\n\rcommon_config\x18\x01 \x01(\x0b\x32\x42.envoy.extensions.access_loggers.grpc.v3.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:7\x9a\xc5\x88\x1e\x32\n0envoy.config.accesslog.v2.TcpGrpcAccessLogConfig\"\x9e\x04\n\x19\x43ommonGrpcAccessLogConfig\x12\x19\n\x08log_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32!.envoy.config.core.v3.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12I\n\x15transport_api_version\x18\x06 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x42\n\x15\x62uffer_flush_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x37\n\x11\x62uffer_size_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12#\n\x1b\x66ilter_state_objects_to_log\x18\x05 \x03(\t\x12\x43\n\x18grpc_stream_retry_policy\x18\x07 \x01(\x0b\x32!.envoy.config.core.v3.RetryPolicy\x12\x35\n\x0b\x63ustom_tags\x18\x08 \x03(\x0b\x32 .envoy.type.tracing.v3.CustomTag::\x9a\xc5\x88\x1e\x35\n3envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\xa2\x01\n5io.envoyproxy.envoy.extensions.access_loggers.grpc.v3B\x08\x41lsProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/grpc/v3;grpcv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.access_loggers.grpc.v3.als_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5io.envoyproxy.envoy.extensions.access_loggers.grpc.v3B\010AlsProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/access_loggers/grpc/v3;grpcv3\272\200\310\321\006\002\020\002'
  _HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _HTTPGRPCACCESSLOGCONFIG._options = None
  _HTTPGRPCACCESSLOGCONFIG._serialized_options = b'\232\305\210\0363\n1envoy.config.accesslog.v2.HttpGrpcAccessLogConfig'
  _TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TCPGRPCACCESSLOGCONFIG._options = None
  _TCPGRPCACCESSLOGCONFIG._serialized_options = b'\232\305\210\0362\n0envoy.config.accesslog.v2.TcpGrpcAccessLogConfig'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._serialized_options = b'\372B\004r\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['transport_api_version']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _COMMONGRPCACCESSLOGCONFIG._options = None
  _COMMONGRPCACCESSLOGCONFIG._serialized_options = b'\232\305\210\0365\n3envoy.config.accesslog.v2.CommonGrpcAccessLogConfig'
  _globals['_HTTPGRPCACCESSLOGCONFIG']._serialized_start=406
  _globals['_HTTPGRPCACCESSLOGCONFIG']._serialized_end=722
  _globals['_TCPGRPCACCESSLOGCONFIG']._serialized_start=725
  _globals['_TCPGRPCACCESSLOGCONFIG']._serialized_end=907
  _globals['_COMMONGRPCACCESSLOGCONFIG']._serialized_start=910
  _globals['_COMMONGRPCACCESSLOGCONFIG']._serialized_end=1452
# @@protoc_insertion_point(module_scope)
