# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGenvoy/extensions/filters/http/grpc_http1_reverse_bridge/v3/config.proto\x12:envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xc7\x01\n\x0c\x46ilterConfig\x12\x1d\n\x0c\x63ontent_type\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1c\n\x14withhold_grpc_frames\x18\x02 \x01(\x08\x12)\n\x14response_size_header\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xc8\x01\x00:O\x9a\xc5\x88\x1eJ\nHenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfig\"\x81\x01\n\x14\x46ilterConfigPerRoute\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08:W\x9a\xc5\x88\x1eR\nPenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfigPerRouteB\xe0\x01\nHio.envoyproxy.envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3B\x0b\x43onfigProtoP\x01Z}github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3;grpc_http1_reverse_bridgev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nHio.envoyproxy.envoy.extensions.filters.http.grpc_http1_reverse_bridge.v3B\013ConfigProtoP\001Z}github.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_http1_reverse_bridge/v3;grpc_http1_reverse_bridgev3\272\200\310\321\006\002\020\002'
  _FILTERCONFIG.fields_by_name['content_type']._options = None
  _FILTERCONFIG.fields_by_name['content_type']._serialized_options = b'\372B\004r\002\020\001'
  _FILTERCONFIG.fields_by_name['response_size_header']._options = None
  _FILTERCONFIG.fields_by_name['response_size_header']._serialized_options = b'\372B\010r\006\300\001\001\310\001\000'
  _FILTERCONFIG._options = None
  _FILTERCONFIG._serialized_options = b'\232\305\210\036J\nHenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfig'
  _FILTERCONFIGPERROUTE._options = None
  _FILTERCONFIGPERROUTE._serialized_options = b'\232\305\210\036R\nPenvoy.config.filter.http.grpc_http1_reverse_bridge.v2alpha1.FilterConfigPerRoute'
  _globals['_FILTERCONFIG']._serialized_start=227
  _globals['_FILTERCONFIG']._serialized_end=426
  _globals['_FILTERCONFIGPERROUTE']._serialized_start=429
  _globals['_FILTERCONFIGPERROUTE']._serialized_end=558
# @@protoc_insertion_point(module_scope)
