# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/buffer/v3/buffer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/filters/http/buffer/v3/buffer.proto\x12\'envoy.extensions.filters.http.buffer.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x87\x01\n\x06\x42uffer\x12\x45\n\x11max_request_bytes\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x02 \x00\x8a\x01\x02\x10\x01:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.buffer.v2.BufferJ\x04\x08\x02\x10\x03\"\xc5\x01\n\x0e\x42ufferPerRoute\x12\x1b\n\x08\x64isabled\x18\x01 \x01(\x08\x42\x07\xfa\x42\x04j\x02\x08\x01H\x00\x12K\n\x06\x62uffer\x18\x02 \x01(\x0b\x32/.envoy.extensions.filters.http.buffer.v3.BufferB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01H\x00:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.http.buffer.v2.BufferPerRouteB\x0f\n\x08override\x12\x03\xf8\x42\x01\x42\xa7\x01\n5io.envoyproxy.envoy.extensions.filters.http.buffer.v3B\x0b\x42ufferProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/buffer/v3;bufferv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.buffer.v3.buffer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5io.envoyproxy.envoy.extensions.filters.http.buffer.v3B\013BufferProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/buffer/v3;bufferv3\272\200\310\321\006\002\020\002'
  _BUFFER.fields_by_name['max_request_bytes']._options = None
  _BUFFER.fields_by_name['max_request_bytes']._serialized_options = b'\372B\t*\002 \000\212\001\002\020\001'
  _BUFFER._options = None
  _BUFFER._serialized_options = b'\232\305\210\036+\n)envoy.config.filter.http.buffer.v2.Buffer'
  _BUFFERPERROUTE.oneofs_by_name['override']._options = None
  _BUFFERPERROUTE.oneofs_by_name['override']._serialized_options = b'\370B\001'
  _BUFFERPERROUTE.fields_by_name['disabled']._options = None
  _BUFFERPERROUTE.fields_by_name['disabled']._serialized_options = b'\372B\004j\002\010\001'
  _BUFFERPERROUTE.fields_by_name['buffer']._options = None
  _BUFFERPERROUTE.fields_by_name['buffer']._serialized_options = b'\372B\005\212\001\002\020\001'
  _BUFFERPERROUTE._options = None
  _BUFFERPERROUTE._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.http.buffer.v2.BufferPerRoute'
  _globals['_BUFFER']._serialized_start=221
  _globals['_BUFFER']._serialized_end=356
  _globals['_BUFFERPERROUTE']._serialized_start=359
  _globals['_BUFFERPERROUTE']._serialized_end=556
# @@protoc_insertion_point(module_scope)
