# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/auth/v2alpha/external_auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.auth.v2 import external_auth_pb2 as envoy_dot_service_dot_auth_dot_v2_dot_external__auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.envoy/service/auth/v2alpha/external_auth.proto\x12\x1a\x65nvoy.service.auth.v2alpha\x1a)envoy/service/auth/v2/external_auth.proto2c\n\rAuthorization\x12R\n\x05\x43heck\x12#.envoy.service.auth.v2.CheckRequest\x1a$.envoy.service.auth.v2.CheckResponseB{\n(io.envoyproxy.envoy.service.auth.v2alphaB\nCertsProtoP\x01ZAgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.auth.v2alpha.external_auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.auth.v2alphaB\nCertsProtoP\001ZAgithub.com/envoyproxy/go-control-plane/envoy/service/auth/v2alpha'
  _globals['_AUTHORIZATION']._serialized_start=121
  _globals['_AUTHORIZATION']._serialized_end=220
# @@protoc_insertion_point(module_scope)
