# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/router/v3/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.accesslog.v3 import accesslog_pb2 as envoy_dot_config_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.extensions.filters.network.http_connection_manager.v3 import http_connection_manager_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_http__connection__manager_dot_v3_dot_http__connection__manager__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/filters/http/router/v3/router.proto\x12\'envoy.extensions.filters.http.router.v3\x1a)envoy/config/accesslog/v3/accesslog.proto\x1aYenvoy/extensions/filters/network/http_connection_manager/v3/http_connection_manager.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xda\x06\n\x06Router\x12\x31\n\rdynamic_stats\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x18\n\x10start_child_span\x18\x02 \x01(\x08\x12:\n\x0cupstream_log\x18\x03 \x03(\x0b\x32$.envoy.config.accesslog.v3.AccessLog\x12\x66\n\x14upstream_log_options\x18\t \x01(\x0b\x32H.envoy.extensions.filters.http.router.v3.Router.UpstreamAccessLogOptions\x12\x1e\n\x16suppress_envoy_headers\x18\x04 \x01(\x08\x12\xb3\x01\n\x14strict_check_headers\x18\x05 \x03(\tB\x94\x01\xfa\x42\x90\x01\x92\x01\x8c\x01\"\x89\x01r\x86\x01R\x1ex-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\x13x-envoy-max-retriesR\x15x-envoy-retry-grpc-onR\x10x-envoy-retry-on\x12#\n\x1brespect_expected_rq_timeout\x18\x06 \x01(\x08\x12\x30\n(suppress_grpc_request_failure_code_stats\x18\x07 \x01(\x08\x12\x66\n\x15upstream_http_filters\x18\x08 \x03(\x0b\x32G.envoy.extensions.filters.network.http_connection_manager.v3.HttpFilter\x1a\x97\x01\n\x18UpstreamAccessLogOptions\x12-\n%flush_upstream_log_on_upstream_stream\x18\x01 \x01(\x08\x12L\n\x1bupstream_log_flush_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xfa\x42\t\xaa\x01\x06\x32\x04\x10\xc0\x84=:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.http.router.v2.RouterB\xa7\x01\n5io.envoyproxy.envoy.extensions.filters.http.router.v3B\x0bRouterProtoP\x01ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/router/v3;routerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.router.v3.router_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n5io.envoyproxy.envoy.extensions.filters.http.router.v3B\013RouterProtoP\001ZWgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/router/v3;routerv3\272\200\310\321\006\002\020\002'
  _ROUTER_UPSTREAMACCESSLOGOPTIONS.fields_by_name['upstream_log_flush_interval']._options = None
  _ROUTER_UPSTREAMACCESSLOGOPTIONS.fields_by_name['upstream_log_flush_interval']._serialized_options = b'\372B\t\252\001\0062\004\020\300\204='
  _ROUTER.fields_by_name['strict_check_headers']._options = None
  _ROUTER.fields_by_name['strict_check_headers']._serialized_options = b'\372B\220\001\222\001\214\001\"\211\001r\206\001R\036x-envoy-upstream-rq-timeout-msR&x-envoy-upstream-rq-per-try-timeout-msR\023x-envoy-max-retriesR\025x-envoy-retry-grpc-onR\020x-envoy-retry-on'
  _ROUTER._options = None
  _ROUTER._serialized_options = b'\232\305\210\036+\n)envoy.config.filter.http.router.v2.Router'
  _globals['_ROUTER']._serialized_start=387
  _globals['_ROUTER']._serialized_end=1245
  _globals['_ROUTER_UPSTREAMACCESSLOGOPTIONS']._serialized_start=1044
  _globals['_ROUTER_UPSTREAMACCESSLOGOPTIONS']._serialized_end=1195
# @@protoc_insertion_point(module_scope)
