# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/data/tap/v2alpha/http.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.data.tap.v2alpha import common_pb2 as envoy_dot_data_dot_tap_dot_v2alpha_dot_common__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/data/tap/v2alpha/http.proto\x12\x16\x65nvoy.data.tap.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a#envoy/data/tap/v2alpha/common.proto\x1a\x1dudpa/annotations/status.proto\"\xb7\x02\n\x11HttpBufferedTrace\x12\x42\n\x07request\x18\x01 \x01(\x0b\x32\x31.envoy.data.tap.v2alpha.HttpBufferedTrace.Message\x12\x43\n\x08response\x18\x02 \x01(\x0b\x32\x31.envoy.data.tap.v2alpha.HttpBufferedTrace.Message\x1a\x98\x01\n\x07Message\x12/\n\x07headers\x18\x01 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\x12*\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.Body\x12\x30\n\x08trailers\x18\x03 \x03(\x0b\x32\x1e.envoy.api.v2.core.HeaderValue\"\x9e\x03\n\x18HttpStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x37\n\x0frequest_headers\x18\x02 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12:\n\x12request_body_chunk\x18\x03 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.BodyH\x00\x12\x38\n\x10request_trailers\x18\x04 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12\x38\n\x10response_headers\x18\x05 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x12;\n\x13response_body_chunk\x18\x06 \x01(\x0b\x32\x1c.envoy.data.tap.v2alpha.BodyH\x00\x12\x39\n\x11response_trailers\x18\x07 \x01(\x0b\x32\x1c.envoy.api.v2.core.HeaderMapH\x00\x42\x0f\n\rmessage_pieceBz\n$io.envoyproxy.envoy.data.tap.v2alphaB\tHttpProtoP\x01Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v2alpha.http_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.data.tap.v2alphaB\tHttpProtoP\001Z=github.com/envoyproxy/go-control-plane/envoy/data/tap/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_HTTPBUFFEREDTRACE']._serialized_start=160
  _globals['_HTTPBUFFEREDTRACE']._serialized_end=471
  _globals['_HTTPBUFFEREDTRACE_MESSAGE']._serialized_start=319
  _globals['_HTTPBUFFEREDTRACE_MESSAGE']._serialized_end=471
  _globals['_HTTPSTREAMEDTRACESEGMENT']._serialized_start=474
  _globals['_HTTPSTREAMEDTRACESEGMENT']._serialized_end=888
# @@protoc_insertion_point(module_scope)
