# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/discovery/v2/hds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import health_check_pb2 as envoy_dot_api_dot_v2_dot_core_dot_health__check__pb2
from envoy.api.v2.endpoint import endpoint_components_pb2 as envoy_dot_api_dot_v2_dot_endpoint_dot_endpoint__components__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$envoy/service/discovery/v2/hds.proto\x12\x1a\x65nvoy.service.discovery.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/api/v2/core/health_check.proto\x1a/envoy/api/v2/endpoint/endpoint_components.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\x87\x01\n\nCapability\x12O\n\x16health_check_protocols\x18\x01 \x03(\x0e\x32/.envoy.service.discovery.v2.Capability.Protocol\"(\n\x08Protocol\x12\x08\n\x04HTTP\x10\x00\x12\x07\n\x03TCP\x10\x01\x12\t\n\x05REDIS\x10\x02\"w\n\x12HealthCheckRequest\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12:\n\ncapability\x18\x02 \x01(\x0b\x32&.envoy.service.discovery.v2.Capability\"{\n\x0e\x45ndpointHealth\x12\x31\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.endpoint.Endpoint\x12\x36\n\rhealth_status\x18\x02 \x01(\x0e\x32\x1f.envoy.api.v2.core.HealthStatus\"^\n\x16\x45ndpointHealthResponse\x12\x44\n\x10\x65ndpoints_health\x18\x01 \x03(\x0b\x32*.envoy.service.discovery.v2.EndpointHealth\"\xe4\x01\n*HealthCheckRequestOrEndpointHealthResponse\x12N\n\x14health_check_request\x18\x01 \x01(\x0b\x32..envoy.service.discovery.v2.HealthCheckRequestH\x00\x12V\n\x18\x65ndpoint_health_response\x18\x02 \x01(\x0b\x32\x32.envoy.service.discovery.v2.EndpointHealthResponseH\x00\x42\x0e\n\x0crequest_type\"v\n\x11LocalityEndpoints\x12-\n\x08locality\x18\x01 \x01(\x0b\x32\x1b.envoy.api.v2.core.Locality\x12\x32\n\tendpoints\x18\x02 \x03(\x0b\x32\x1f.envoy.api.v2.endpoint.Endpoint\"\xac\x01\n\x12\x43lusterHealthCheck\x12\x14\n\x0c\x63luster_name\x18\x01 \x01(\t\x12\x35\n\rhealth_checks\x18\x02 \x03(\x0b\x32\x1e.envoy.api.v2.core.HealthCheck\x12I\n\x12locality_endpoints\x18\x03 \x03(\x0b\x32-.envoy.service.discovery.v2.LocalityEndpoints\"\x92\x01\n\x14HealthCheckSpecifier\x12M\n\x15\x63luster_health_checks\x18\x01 \x03(\x0b\x32..envoy.service.discovery.v2.ClusterHealthCheck\x12+\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xe4\x02\n\x16HealthDiscoveryService\x12\x93\x01\n\x11StreamHealthCheck\x12\x46.envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse\x1a\x30.envoy.service.discovery.v2.HealthCheckSpecifier\"\x00(\x01\x30\x01\x12\xb3\x01\n\x10\x46\x65tchHealthCheck\x12\x46.envoy.service.discovery.v2.HealthCheckRequestOrEndpointHealthResponse\x1a\x30.envoy.service.discovery.v2.HealthCheckSpecifier\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v2/discovery:health_check:\x01*B\xac\x01\n(io.envoyproxy.envoy.service.discovery.v2B\x08HdsProtoP\x01ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.service.health.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.discovery.v2.hds_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(io.envoyproxy.envoy.service.discovery.v2B\010HdsProtoP\001ZMgithub.com/envoyproxy/go-control-plane/envoy/service/discovery/v2;discoveryv2\362\230\376\217\005\031\022\027envoy.service.health.v3\272\200\310\321\006\002\020\001'
  _HEALTHDISCOVERYSERVICE.methods_by_name['FetchHealthCheck']._options = None
  _HEALTHDISCOVERYSERVICE.methods_by_name['FetchHealthCheck']._serialized_options = b'\202\323\344\223\002\037\"\032/v2/discovery:health_check:\001*'
  _globals['_CAPABILITY']._serialized_start=311
  _globals['_CAPABILITY']._serialized_end=446
  _globals['_CAPABILITY_PROTOCOL']._serialized_start=406
  _globals['_CAPABILITY_PROTOCOL']._serialized_end=446
  _globals['_HEALTHCHECKREQUEST']._serialized_start=448
  _globals['_HEALTHCHECKREQUEST']._serialized_end=567
  _globals['_ENDPOINTHEALTH']._serialized_start=569
  _globals['_ENDPOINTHEALTH']._serialized_end=692
  _globals['_ENDPOINTHEALTHRESPONSE']._serialized_start=694
  _globals['_ENDPOINTHEALTHRESPONSE']._serialized_end=788
  _globals['_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE']._serialized_start=791
  _globals['_HEALTHCHECKREQUESTORENDPOINTHEALTHRESPONSE']._serialized_end=1019
  _globals['_LOCALITYENDPOINTS']._serialized_start=1021
  _globals['_LOCALITYENDPOINTS']._serialized_end=1139
  _globals['_CLUSTERHEALTHCHECK']._serialized_start=1142
  _globals['_CLUSTERHEALTHCHECK']._serialized_end=1314
  _globals['_HEALTHCHECKSPECIFIER']._serialized_start=1317
  _globals['_HEALTHCHECKSPECIFIER']._serialized_end=1463
  _globals['_HEALTHDISCOVERYSERVICE']._serialized_start=1466
  _globals['_HEALTHDISCOVERYSERVICE']._serialized_end=1822
# @@protoc_insertion_point(module_scope)
