# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/fault/v3/fault.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.extensions.filters.common.fault.v3 import fault_pb2 as envoy_dot_extensions_dot_filters_dot_common_dot_fault_dot_v3_dot_fault__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/filters/http/fault/v3/fault.proto\x12&envoy.extensions.filters.http.fault.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\x34\x65nvoy/extensions/filters/common/fault/v3/fault.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xf3\x02\n\nFaultAbort\x12\"\n\x0bhttp_status\x18\x02 \x01(\rB\x0b\xfa\x42\x08*\x06\x10\xd8\x04(\xc8\x01H\x00\x12\x15\n\x0bgrpc_status\x18\x05 \x01(\rH\x00\x12V\n\x0cheader_abort\x18\x04 \x01(\x0b\x32>.envoy.extensions.filters.http.fault.v3.FaultAbort.HeaderAbortH\x00\x12\x34\n\npercentage\x18\x03 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x1aN\n\x0bHeaderAbort:?\x9a\xc5\x88\x1e:\n8envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbort:3\x9a\xc5\x88\x1e.\n,envoy.config.filter.http.fault.v2.FaultAbortB\x11\n\nerror_type\x12\x03\xf8\x42\x01J\x04\x08\x01\x10\x02\"\x92\x06\n\tHTTPFault\x12\x43\n\x05\x64\x65lay\x18\x01 \x01(\x0b\x32\x34.envoy.extensions.filters.common.fault.v3.FaultDelay\x12\x41\n\x05\x61\x62ort\x18\x02 \x01(\x0b\x32\x32.envoy.extensions.filters.http.fault.v3.FaultAbort\x12\x18\n\x10upstream_cluster\x18\x03 \x01(\t\x12\x35\n\x07headers\x18\x04 \x03(\x0b\x32$.envoy.config.route.v3.HeaderMatcher\x12\x18\n\x10\x64ownstream_nodes\x18\x05 \x03(\t\x12\x37\n\x11max_active_faults\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12U\n\x13response_rate_limit\x18\x07 \x01(\x0b\x32\x38.envoy.extensions.filters.common.fault.v3.FaultRateLimit\x12\x1d\n\x15\x64\x65lay_percent_runtime\x18\x08 \x01(\t\x12\x1d\n\x15\x61\x62ort_percent_runtime\x18\t \x01(\t\x12\x1e\n\x16\x64\x65lay_duration_runtime\x18\n \x01(\t\x12!\n\x19\x61\x62ort_http_status_runtime\x18\x0b \x01(\t\x12!\n\x19max_active_faults_runtime\x18\x0c \x01(\t\x12+\n#response_rate_limit_percent_runtime\x18\r \x01(\t\x12!\n\x19\x61\x62ort_grpc_status_runtime\x18\x0e \x01(\t\x12(\n disable_downstream_cluster_stats\x18\x0f \x01(\x08\x12\x30\n\x0f\x66ilter_metadata\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct:2\x9a\xc5\x88\x1e-\n+envoy.config.filter.http.fault.v2.HTTPFaultB\xa3\x01\n4io.envoyproxy.envoy.extensions.filters.http.fault.v3B\nFaultProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/fault/v3;faultv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.fault.v3.fault_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.filters.http.fault.v3B\nFaultProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/fault/v3;faultv3\272\200\310\321\006\002\020\002'
  _FAULTABORT_HEADERABORT._options = None
  _FAULTABORT_HEADERABORT._serialized_options = b'\232\305\210\036:\n8envoy.config.filter.http.fault.v2.FaultAbort.HeaderAbort'
  _FAULTABORT.oneofs_by_name['error_type']._options = None
  _FAULTABORT.oneofs_by_name['error_type']._serialized_options = b'\370B\001'
  _FAULTABORT.fields_by_name['http_status']._options = None
  _FAULTABORT.fields_by_name['http_status']._serialized_options = b'\372B\010*\006\020\330\004(\310\001'
  _FAULTABORT._options = None
  _FAULTABORT._serialized_options = b'\232\305\210\036.\n,envoy.config.filter.http.fault.v2.FaultAbort'
  _HTTPFAULT._options = None
  _HTTPFAULT._serialized_options = b'\232\305\210\036-\n+envoy.config.filter.http.fault.v2.HTTPFault'
  _globals['_FAULTABORT']._serialized_start=377
  _globals['_FAULTABORT']._serialized_end=748
  _globals['_FAULTABORT_HEADERABORT']._serialized_start=592
  _globals['_FAULTABORT_HEADERABORT']._serialized_end=670
  _globals['_HTTPFAULT']._serialized_start=751
  _globals['_HTTPFAULT']._serialized_end=1537
# @@protoc_insertion_point(module_scope)
