# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/geoip/v3/geoip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/filters/http/geoip/v3/geoip.proto\x12&envoy.extensions.filters.http.geoip.v3\x1a$envoy/config/core/v3/extension.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xe0\x04\n\x05Geoip\x12K\n\nxff_config\x18\x01 \x01(\x0b\x32\x37.envoy.extensions.filters.http.geoip.v3.Geoip.XffConfig\x12k\n\x12geo_headers_to_add\x18\x02 \x01(\x0b\x32\x45.envoy.extensions.filters.http.geoip.v3.Geoip.GeolocationHeadersToAddB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x46\n\x08provider\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x1a\xa9\x02\n\x17GeolocationHeadersToAdd\x12\x1c\n\x07\x63ountry\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x19\n\x04\x63ity\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1b\n\x06region\x18\x03 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x18\n\x03\x61sn\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1c\n\x07is_anon\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1d\n\x08\x61non_vpn\x18\x06 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12!\n\x0c\x61non_hosting\x18\x07 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1d\n\x08\x61non_tor\x18\x08 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x12\x1f\n\nanon_proxy\x18\t \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x01\xd0\x01\x01\x1a)\n\tXffConfig\x12\x1c\n\x14xff_num_trusted_hops\x18\x01 \x01(\rB\xab\x01\n4io.envoyproxy.envoy.extensions.filters.http.geoip.v3B\nGeoipProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/geoip/v3;geoipv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.geoip.v3.geoip_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.filters.http.geoip.v3B\nGeoipProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/geoip/v3;geoipv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['country']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['country']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['city']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['city']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['region']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['region']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['asn']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['asn']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['is_anon']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['is_anon']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_vpn']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_vpn']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_hosting']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_hosting']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_tor']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_tor']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_proxy']._options = None
  _GEOIP_GEOLOCATIONHEADERSTOADD.fields_by_name['anon_proxy']._serialized_options = b'\372B\010r\006\300\001\001\320\001\001'
  _GEOIP.fields_by_name['geo_headers_to_add']._options = None
  _GEOIP.fields_by_name['geo_headers_to_add']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GEOIP.fields_by_name['provider']._options = None
  _GEOIP.fields_by_name['provider']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_GEOIP']._serialized_start=222
  _globals['_GEOIP']._serialized_end=830
  _globals['_GEOIP_GEOLOCATIONHEADERSTOADD']._serialized_start=490
  _globals['_GEOIP_GEOLOCATIONHEADERSTOADD']._serialized_end=787
  _globals['_GEOIP_XFFCONFIG']._serialized_start=789
  _globals['_GEOIP_XFFCONFIG']._serialized_end=830
# @@protoc_insertion_point(module_scope)
