# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/http/cache/file_system_http_cache/v3/file_system_http_cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.common.async_files.v3 import async_file_manager_pb2 as envoy_dot_extensions_dot_common_dot_async__files_dot_v3_dot_async__file__manager__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRenvoy/extensions/http/cache/file_system_http_cache/v3/file_system_http_cache.proto\x12\x35\x65nvoy.extensions.http.cache.file_system_http_cache.v3\x1a?envoy/extensions/common/async_files/v3/async_file_manager.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x9f\x04\n\x19\x46ileSystemHttpCacheConfig\x12`\n\x0emanager_config\x18\x01 \x01(\x0b\x32>.envoy.extensions.common.async_files.v3.AsyncFileManagerConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x1b\n\ncache_path\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12:\n\x14max_cache_size_bytes\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12K\n%max_individual_cache_entry_size_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12;\n\x15max_cache_entry_count\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1a\n\x12\x63\x61\x63he_subdivisions\x18\x06 \x01(\r\x12\x16\n\x0e\x65vict_fraction\x18\x07 \x01(\x02\x12\x36\n\x13max_eviction_period\x18\x08 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13min_eviction_period\x18\t \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x19\n\x11\x63reate_cache_path\x18\n \x01(\x08\x42\xe8\x01\nCio.envoyproxy.envoy.extensions.http.cache.file_system_http_cache.v3B\x18\x46ileSystemHttpCacheProtoP\x01Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/http/cache/file_system_http_cache/v3;file_system_http_cachev3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.cache.file_system_http_cache.v3.file_system_http_cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCio.envoyproxy.envoy.extensions.http.cache.file_system_http_cache.v3B\030FileSystemHttpCacheProtoP\001Zugithub.com/envoyproxy/go-control-plane/envoy/extensions/http/cache/file_system_http_cache/v3;file_system_http_cachev3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _FILESYSTEMHTTPCACHECONFIG.fields_by_name['manager_config']._options = None
  _FILESYSTEMHTTPCACHECONFIG.fields_by_name['manager_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _FILESYSTEMHTTPCACHECONFIG.fields_by_name['cache_path']._options = None
  _FILESYSTEMHTTPCACHECONFIG.fields_by_name['cache_path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_FILESYSTEMHTTPCACHECONFIG']._serialized_start=360
  _globals['_FILESYSTEMHTTPCACHECONFIG']._serialized_end=903
# @@protoc_insertion_point(module_scope)
