# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/accesslog/v2/als.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import grpc_service_pb2 as envoy_dot_api_dot_v2_dot_core_dot_grpc__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/config/accesslog/v2/als.proto\x12\x19\x65nvoy.config.accesslog.v2\x1a$envoy/api/v2/core/grpc_service.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf4\x01\n\x17HttpGrpcAccessLogConfig\x12U\n\rcommon_config\x18\x01 \x01(\x0b\x32\x34.envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12)\n!additional_request_headers_to_log\x18\x02 \x03(\t\x12*\n\"additional_response_headers_to_log\x18\x03 \x03(\t\x12+\n#additional_response_trailers_to_log\x18\x04 \x03(\t\"o\n\x16TcpGrpcAccessLogConfig\x12U\n\rcommon_config\x18\x01 \x01(\x0b\x32\x34.envoy.config.accesslog.v2.CommonGrpcAccessLogConfigB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x98\x02\n\x19\x43ommonGrpcAccessLogConfig\x12\x19\n\x08log_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12>\n\x0cgrpc_service\x18\x02 \x01(\x0b\x32\x1e.envoy.api.v2.core.GrpcServiceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x42\n\x15\x62uffer_flush_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x37\n\x11\x62uffer_size_bytes\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12#\n\x1b\x66ilter_state_objects_to_log\x18\x05 \x03(\tB\xba\x01\n\'io.envoyproxy.envoy.config.accesslog.v2B\x08\x41lsProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v2;accesslogv2\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.access_loggers.grpc.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.accesslog.v2.als_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'io.envoyproxy.envoy.config.accesslog.v2B\010AlsProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v2;accesslogv2\362\230\376\217\005)\022\'envoy.extensions.access_loggers.grpc.v3\272\200\310\321\006\002\020\001'
  _HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _HTTPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._options = None
  _TCPGRPCACCESSLOGCONFIG.fields_by_name['common_config']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['log_name']._serialized_options = b'\372B\004r\002 \001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['grpc_service']._serialized_options = b'\372B\005\212\001\002\020\001'
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._options = None
  _COMMONGRPCACCESSLOGCONFIG.fields_by_name['buffer_flush_interval']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_HTTPGRPCACCESSLOGCONFIG']._serialized_start=257
  _globals['_HTTPGRPCACCESSLOGCONFIG']._serialized_end=501
  _globals['_TCPGRPCACCESSLOGCONFIG']._serialized_start=503
  _globals['_TCPGRPCACCESSLOGCONFIG']._serialized_end=614
  _globals['_COMMONGRPCACCESSLOGCONFIG']._serialized_start=617
  _globals['_COMMONGRPCACCESSLOGCONFIG']._serialized_end=897
# @@protoc_insertion_point(module_scope)
