# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/tls/v3/cert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.transport_sockets.tls.v3 import common_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_common__pb2
from envoy.extensions.transport_sockets.tls.v3 import secret_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_secret__pb2
from envoy.extensions.transport_sockets.tls.v3 import tls_pb2 as envoy_dot_extensions_dot_transport__sockets_dot_tls_dot_v3_dot_tls__pb2

from envoy.extensions.transport_sockets.tls.v3.common_pb2 import *
from envoy.extensions.transport_sockets.tls.v3.secret_pb2 import *
from envoy.extensions.transport_sockets.tls.v3.tls_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4envoy/extensions/transport_sockets/tls/v3/cert.proto\x12)envoy.extensions.transport_sockets.tls.v3\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/common.proto\x1a\x36\x65nvoy/extensions/transport_sockets/tls/v3/secret.proto\x1a\x33\x65nvoy/extensions/transport_sockets/tls/v3/tls.protoB\x9e\x01\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\tCertProtoP\x01ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3P\x00P\x01P\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.tls.v3.cert_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7io.envoyproxy.envoy.extensions.transport_sockets.tls.v3B\tCertProtoP\001ZVgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/tls/v3;tlsv3'
# @@protoc_insertion_point(module_scope)
