# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/cache/v3/cache.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/extensions/filters/http/cache/v3/cache.proto\x12&envoy.extensions.filters.http.cache.v3\x1a,envoy/config/route/v3/route_components.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x91\x05\n\x0b\x43\x61\x63heConfig\x12*\n\x0ctyped_config\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12,\n\x08\x64isabled\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x14\x61llowed_vary_headers\x18\x02 \x03(\x0b\x32$.envoy.type.matcher.v3.StringMatcher\x12`\n\x12key_creator_params\x18\x03 \x01(\x0b\x32\x44.envoy.extensions.filters.http.cache.v3.CacheConfig.KeyCreatorParams\x12\x16\n\x0emax_body_bytes\x18\x04 \x01(\r\x1a\xae\x02\n\x10KeyCreatorParams\x12\x16\n\x0e\x65xclude_scheme\x18\x01 \x01(\x08\x12\x14\n\x0c\x65xclude_host\x18\x02 \x01(\x08\x12O\n\x19query_parameters_included\x18\x03 \x03(\x0b\x32,.envoy.config.route.v3.QueryParameterMatcher\x12O\n\x19query_parameters_excluded\x18\x04 \x03(\x0b\x32,.envoy.config.route.v3.QueryParameterMatcher:J\x9a\xc5\x88\x1e\x45\nCenvoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams:9\x9a\xc5\x88\x1e\x34\n2envoy.config.filter.http.cache.v2alpha.CacheConfigB\xa3\x01\n4io.envoyproxy.envoy.extensions.filters.http.cache.v3B\nCacheProtoP\x01ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/cache/v3;cachev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.cache.v3.cache_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n4io.envoyproxy.envoy.extensions.filters.http.cache.v3B\nCacheProtoP\001ZUgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/cache/v3;cachev3\272\200\310\321\006\002\020\002'
  _CACHECONFIG_KEYCREATORPARAMS._options = None
  _CACHECONFIG_KEYCREATORPARAMS._serialized_options = b'\232\305\210\036E\nCenvoy.config.filter.http.cache.v2alpha.CacheConfig.KeyCreatorParams'
  _CACHECONFIG._options = None
  _CACHECONFIG._serialized_options = b'\232\305\210\0364\n2envoy.config.filter.http.cache.v2alpha.CacheConfig'
  _globals['_CACHECONFIG']._serialized_start=302
  _globals['_CACHECONFIG']._serialized_end=959
  _globals['_CACHECONFIG_KEYCREATORPARAMS']._serialized_start=598
  _globals['_CACHECONFIG_KEYCREATORPARAMS']._serialized_end=900
# @@protoc_insertion_point(module_scope)
