# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/grpc_json_transcoder/v3/transcoder.proto\x12\x35\x65nvoy.extensions.filters.http.grpc_json_transcoder.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xde\x0b\n\x12GrpcJsonTranscoder\x12\x1a\n\x10proto_descriptor\x18\x01 \x01(\tH\x00\x12\x1e\n\x14proto_descriptor_bin\x18\x04 \x01(\x0cH\x00\x12\x10\n\x08services\x18\x02 \x03(\t\x12m\n\rprint_options\x18\x03 \x01(\x0b\x32V.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.PrintOptions\x12$\n\x1cmatch_incoming_request_route\x18\x05 \x01(\x08\x12 \n\x18ignored_query_parameters\x18\x06 \x03(\t\x12\x14\n\x0c\x61uto_mapping\x18\x07 \x01(\x08\x12\'\n\x1fignore_unknown_query_parameters\x18\x08 \x01(\x08\x12\x1b\n\x13\x63onvert_grpc_status\x18\t \x01(\x08\x12~\n\x11url_unescape_spec\x18\n \x01(\x0e\x32Y.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.UrlUnescapeSpecB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12!\n\x19query_param_unescape_plus\x18\x0c \x01(\x08\x12&\n\x1ematch_unregistered_custom_verb\x18\r \x01(\x08\x12\x86\x01\n\x1arequest_validation_options\x18\x0b \x01(\x0b\x32\x62.envoy.extensions.filters.http.grpc_json_transcoder.v3.GrpcJsonTranscoder.RequestValidationOptions\x12%\n\x1d\x63\x61se_insensitive_enum_parsing\x18\x0e \x01(\x08\x12\x44\n\x15max_request_body_size\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x45\n\x16max_response_body_size\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x1a\x86\x02\n\x0cPrintOptions\x12\x16\n\x0e\x61\x64\x64_whitespace\x18\x01 \x01(\x08\x12%\n\x1d\x61lways_print_primitive_fields\x18\x02 \x01(\x08\x12\"\n\x1a\x61lways_print_enums_as_ints\x18\x03 \x01(\x08\x12\"\n\x1apreserve_proto_field_names\x18\x04 \x01(\x08\x12 \n\x18stream_newline_delimited\x18\x05 \x01(\x08:M\x9a\xc5\x88\x1eH\nFenvoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions\x1a\x90\x01\n\x18RequestValidationOptions\x12\x1d\n\x15reject_unknown_method\x18\x01 \x01(\x08\x12\'\n\x1freject_unknown_query_parameters\x18\x02 \x01(\x08\x12,\n$reject_binding_body_field_collisions\x18\x03 \x01(\x08\"j\n\x0fUrlUnescapeSpec\x12\"\n\x1e\x41LL_CHARACTERS_EXCEPT_RESERVED\x10\x00\x12\x1f\n\x1b\x41LL_CHARACTERS_EXCEPT_SLASH\x10\x01\x12\x12\n\x0e\x41LL_CHARACTERS\x10\x02:@\x9a\xc5\x88\x1e;\n9envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoderB\x15\n\x0e\x64\x65scriptor_set\x12\x03\xf8\x42\x01\x42\xd5\x01\nCio.envoyproxy.envoy.extensions.filters.http.grpc_json_transcoder.v3B\x0fTranscoderProtoP\x01Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_json_transcoder/v3;grpc_json_transcoderv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.grpc_json_transcoder.v3.transcoder_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nCio.envoyproxy.envoy.extensions.filters.http.grpc_json_transcoder.v3B\017TranscoderProtoP\001Zsgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/grpc_json_transcoder/v3;grpc_json_transcoderv3\272\200\310\321\006\002\020\002'
  _GRPCJSONTRANSCODER_PRINTOPTIONS._options = None
  _GRPCJSONTRANSCODER_PRINTOPTIONS._serialized_options = b'\232\305\210\036H\nFenvoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder.PrintOptions'
  _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']._options = None
  _GRPCJSONTRANSCODER.oneofs_by_name['descriptor_set']._serialized_options = b'\370B\001'
  _GRPCJSONTRANSCODER.fields_by_name['url_unescape_spec']._options = None
  _GRPCJSONTRANSCODER.fields_by_name['url_unescape_spec']._serialized_options = b'\372B\005\202\001\002\020\001'
  _GRPCJSONTRANSCODER.fields_by_name['max_request_body_size']._options = None
  _GRPCJSONTRANSCODER.fields_by_name['max_request_body_size']._serialized_options = b'\372B\004*\002 \000'
  _GRPCJSONTRANSCODER.fields_by_name['max_response_body_size']._options = None
  _GRPCJSONTRANSCODER.fields_by_name['max_response_body_size']._serialized_options = b'\372B\004*\002 \000'
  _GRPCJSONTRANSCODER._options = None
  _GRPCJSONTRANSCODER._serialized_options = b'\232\305\210\036;\n9envoy.config.filter.http.transcoder.v2.GrpcJsonTranscoder'
  _globals['_GRPCJSONTRANSCODER']._serialized_start=253
  _globals['_GRPCJSONTRANSCODER']._serialized_end=1755
  _globals['_GRPCJSONTRANSCODER_PRINTOPTIONS']._serialized_start=1149
  _globals['_GRPCJSONTRANSCODER_PRINTOPTIONS']._serialized_end=1411
  _globals['_GRPCJSONTRANSCODER_REQUESTVALIDATIONOPTIONS']._serialized_start=1414
  _globals['_GRPCJSONTRANSCODER_REQUESTVALIDATIONOPTIONS']._serialized_end=1558
  _globals['_GRPCJSONTRANSCODER_URLUNESCAPESPEC']._serialized_start=1560
  _globals['_GRPCJSONTRANSCODER_URLUNESCAPESPEC']._serialized_end=1666
# @@protoc_insertion_point(module_scope)
