# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/cluster/circuit_breaker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type import percent_pb2 as envoy_dot_type_dot_percent__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*envoy/api/v2/cluster/circuit_breaker.proto\x12\x14\x65nvoy.api.v2.cluster\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x18\x65nvoy/type/percent.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa2\x05\n\x0f\x43ircuitBreakers\x12\x44\n\nthresholds\x18\x01 \x03(\x0b\x32\x30.envoy.api.v2.cluster.CircuitBreakers.Thresholds\x1a\xc8\x04\n\nThresholds\x12>\n\x08priority\x18\x01 \x01(\x0e\x32\".envoy.api.v2.core.RoutingPriorityB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x35\n\x0fmax_connections\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12:\n\x14max_pending_requests\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x32\n\x0cmax_requests\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bmax_retries\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12R\n\x0cretry_budget\x18\x08 \x01(\x0b\x32<.envoy.api.v2.cluster.CircuitBreakers.Thresholds.RetryBudget\x12\x17\n\x0ftrack_remaining\x18\x06 \x01(\x08\x12:\n\x14max_connection_pools\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x1aw\n\x0bRetryBudget\x12+\n\x0e\x62udget_percent\x18\x01 \x01(\x0b\x32\x13.envoy.type.Percent\x12;\n\x15min_retry_concurrency\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xd4\x01\n\"io.envoyproxy.envoy.api.v2.clusterB\x13\x43ircuitBreakerProtoP\x01Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\xaa\x02\x16\x45nvoy.Api.V2.ClusterNS\xea\x02\x19\x45nvoy::Api::V2::ClusterNS\xf2\x98\xfe\x8f\x05\x19\x12\x17\x65nvoy.config.cluster.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.cluster.circuit_breaker_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"io.envoyproxy.envoy.api.v2.clusterB\023CircuitBreakerProtoP\001Z;github.com/envoyproxy/go-control-plane/envoy/api/v2/cluster\252\002\026Envoy.Api.V2.ClusterNS\352\002\031Envoy::Api::V2::ClusterNS\362\230\376\217\005\031\022\027envoy.config.cluster.v3\272\200\310\321\006\002\020\001'
  _CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority']._options = None
  _CIRCUITBREAKERS_THRESHOLDS.fields_by_name['priority']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_CIRCUITBREAKERS']._serialized_start=245
  _globals['_CIRCUITBREAKERS']._serialized_end=919
  _globals['_CIRCUITBREAKERS_THRESHOLDS']._serialized_start=335
  _globals['_CIRCUITBREAKERS_THRESHOLDS']._serialized_end=919
  _globals['_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET']._serialized_start=800
  _globals['_CIRCUITBREAKERS_THRESHOLDS_RETRYBUDGET']._serialized_end=919
# @@protoc_insertion_point(module_scope)
