# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/discovery.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65nvoy/api/v2/discovery.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x19google/protobuf/any.proto\x1a\x17google/rpc/status.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\"\xbb\x01\n\x10\x44iscoveryRequest\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12%\n\x04node\x18\x02 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12\x16\n\x0eresource_names\x18\x03 \x03(\t\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\x16\n\x0eresponse_nonce\x18\x05 \x01(\t\x12(\n\x0c\x65rror_detail\x18\x06 \x01(\x0b\x32\x12.google.rpc.Status\"\xbb\x01\n\x11\x44iscoveryResponse\x12\x14\n\x0cversion_info\x18\x01 \x01(\t\x12\'\n\tresources\x18\x02 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x0e\n\x06\x63\x61nary\x18\x03 \x01(\x08\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\x12\x36\n\rcontrol_plane\x18\x06 \x01(\x0b\x32\x1f.envoy.api.v2.core.ControlPlane\"\xfd\x02\n\x15\x44\x65ltaDiscoveryRequest\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12\x10\n\x08type_url\x18\x02 \x01(\t\x12 \n\x18resource_names_subscribe\x18\x03 \x03(\t\x12\"\n\x1aresource_names_unsubscribe\x18\x04 \x03(\t\x12\x63\n\x19initial_resource_versions\x18\x05 \x03(\x0b\x32@.envoy.api.v2.DeltaDiscoveryRequest.InitialResourceVersionsEntry\x12\x16\n\x0eresponse_nonce\x18\x06 \x01(\t\x12(\n\x0c\x65rror_detail\x18\x07 \x01(\x0b\x32\x12.google.rpc.Status\x1a>\n\x1cInitialResourceVersionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9c\x01\n\x16\x44\x65ltaDiscoveryResponse\x12\x1b\n\x13system_version_info\x18\x01 \x01(\t\x12)\n\tresources\x18\x02 \x03(\x0b\x32\x16.envoy.api.v2.Resource\x12\x10\n\x08type_url\x18\x04 \x01(\t\x12\x19\n\x11removed_resources\x18\x06 \x03(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\"b\n\x08Resource\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x61liases\x18\x04 \x03(\t\x12\x0f\n\x07version\x18\x01 \x01(\t\x12&\n\x08resource\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x93\x01\n\x1aio.envoyproxy.envoy.api.v2B\x0e\x44iscoveryProtoP\x01Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\xf2\x98\xfe\x8f\x05\x1c\x12\x1a\x65nvoy.service.discovery.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.discovery_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032io.envoyproxy.envoy.api.v2B\016DiscoveryProtoP\001Z9github.com/envoyproxy/go-control-plane/envoy/api/v2;apiv2\362\230\376\217\005\034\022\032envoy.service.discovery.v3\272\200\310\321\006\002\020\001'
  _DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY._options = None
  _DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY._serialized_options = b'8\001'
  _globals['_DISCOVERYREQUEST']._serialized_start=192
  _globals['_DISCOVERYREQUEST']._serialized_end=379
  _globals['_DISCOVERYRESPONSE']._serialized_start=382
  _globals['_DISCOVERYRESPONSE']._serialized_end=569
  _globals['_DELTADISCOVERYREQUEST']._serialized_start=572
  _globals['_DELTADISCOVERYREQUEST']._serialized_end=953
  _globals['_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY']._serialized_start=891
  _globals['_DELTADISCOVERYREQUEST_INITIALRESOURCEVERSIONSENTRY']._serialized_end=953
  _globals['_DELTADISCOVERYRESPONSE']._serialized_start=956
  _globals['_DELTADISCOVERYRESPONSE']._serialized_end=1112
  _globals['_RESOURCE']._serialized_start=1114
  _globals['_RESOURCE']._serialized_end=1212
# @@protoc_insertion_point(module_scope)
